/* Generated by Nim Compiler v2.2.10 */
#define NIM_INTBITS 64

#include "nimbase.h"
#include <string.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix
typedef struct tyObject_BuildCache__lwHTcYFYjgY7FbhZRiNECA tyObject_BuildCache__lwHTcYFYjgY7FbhZRiNECA;
typedef struct tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g;
typedef struct tyObject_Joptions__sSnirGarU4zL21BjW4JcHQ tyObject_Joptions__sSnirGarU4zL21BjW4JcHQ;
typedef struct NimStrPayload NimStrPayload;
typedef struct NimStringV2 NimStringV2;
typedef struct tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA;
typedef struct tyObject_CatchableError__TCF9b1Y9b2ct0xPZvZnaY7gg tyObject_CatchableError__TCF9b1Y9b2ct0xPZvZnaY7gg;
typedef struct Exception Exception;
typedef struct RootObj RootObj;
typedef struct TNimTypeV2 TNimTypeV2;
typedef struct tySequence__S89cE01OvNjsN9c71FKsSrqQ tySequence__S89cE01OvNjsN9c71FKsSrqQ;
typedef struct tySequence__S89cE01OvNjsN9c71FKsSrqQ_Content tySequence__S89cE01OvNjsN9c71FKsSrqQ_Content;
typedef struct tyTuple__M7ImznM2hk9a9beBDTxcwGeg tyTuple__M7ImznM2hk9a9beBDTxcwGeg;
typedef struct tyObject_OrderedTable__ASIVNBCKpz8qGZwzYCCBFQ tyObject_OrderedTable__ASIVNBCKpz8qGZwzYCCBFQ;
typedef struct tySequence__m9axZwxFfhSNLcoofvKZJYA tySequence__m9axZwxFfhSNLcoofvKZJYA;
typedef struct tySequence__m9axZwxFfhSNLcoofvKZJYA_Content tySequence__m9axZwxFfhSNLcoofvKZJYA_Content;
typedef struct tySequence__fXWXs2NlFKREhy9cn6vokJw tySequence__fXWXs2NlFKREhy9cn6vokJw;
typedef struct tySequence__fXWXs2NlFKREhy9cn6vokJw_Content tySequence__fXWXs2NlFKREhy9cn6vokJw_Content;
typedef struct tySequence__4eQHGndY6XBYpFOH09apV8Q tySequence__4eQHGndY6XBYpFOH09apV8Q;
typedef struct tySequence__4eQHGndY6XBYpFOH09apV8Q_Content tySequence__4eQHGndY6XBYpFOH09apV8Q_Content;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ tySequence__sM4lkSb7zS6F7OVMvW9cffQ;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content;
typedef struct tyTuple__UV3llMMYFckfui8YMBuUZA tyTuple__UV3llMMYFckfui8YMBuUZA;
typedef struct tyObject_ToJsonOptions__xxRei9adCn4x50jeG886fag tyObject_ToJsonOptions__xxRei9adCn4x50jeG886fag;
typedef struct tyObject_StackTraceEntry__RcJz5RXFIYjIseutvVFICA tyObject_StackTraceEntry__RcJz5RXFIYjIseutvVFICA;
typedef struct tyTuple__eR5B9b9c9coYBbO09chTvuMqNQ tyTuple__eR5B9b9c9coYBbO09chTvuMqNQ;
struct tyObject_Joptions__sSnirGarU4zL21BjW4JcHQ {
	NIM_BOOL allowExtraKeys;
	NIM_BOOL allowMissingKeys;
};
struct NimStrPayload {
	NI cap;
	NIM_CHAR data[SEQ_DECL_SIZE];
};
struct NimStringV2 {
	NI len;
	NimStrPayload* p;
};
struct TNimTypeV2 {
	void* destructor;
	NI size;
	NI16 align;
	NI16 depth;
	NU32* display;
	void* traceImpl;
	void* typeInfoV1;
	NI flags;
	void* vTable[SEQ_DECL_SIZE];
};
struct RootObj {
	TNimTypeV2* m_type;
};
struct tySequence__S89cE01OvNjsN9c71FKsSrqQ {
  NI len; tySequence__S89cE01OvNjsN9c71FKsSrqQ_Content* p;
};
struct Exception {
	RootObj Sup;
	Exception* parent;
	NCSTRING name;
	NimStringV2 message;
	tySequence__S89cE01OvNjsN9c71FKsSrqQ trace;
	Exception* up;
};
struct tyObject_CatchableError__TCF9b1Y9b2ct0xPZvZnaY7gg {
	Exception Sup;
};
struct tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA {
	tyObject_CatchableError__TCF9b1Y9b2ct0xPZvZnaY7gg Sup;
};
struct tyTuple__M7ImznM2hk9a9beBDTxcwGeg {
	NimStringV2 Field0;
	tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* Field1;
};
typedef NU8 tyEnum_JsonNodeKind__qvXp5fGPKV9a8zGGwjrKjDA;
struct tySequence__m9axZwxFfhSNLcoofvKZJYA {
  NI len; tySequence__m9axZwxFfhSNLcoofvKZJYA_Content* p;
};
struct tyObject_OrderedTable__ASIVNBCKpz8qGZwzYCCBFQ {
	tySequence__m9axZwxFfhSNLcoofvKZJYA data;
	NI counter;
	NI first;
	NI last;
};
struct tySequence__fXWXs2NlFKREhy9cn6vokJw {
  NI len; tySequence__fXWXs2NlFKREhy9cn6vokJw_Content* p;
};
struct tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g {
	NIM_BOOL isUnquoted;
	tyEnum_JsonNodeKind__qvXp5fGPKV9a8zGGwjrKjDA kind;
union{
	struct {
	NimStringV2 str;
} _kind_1;
	struct {
	NI64 num;
} _kind_2;
	struct {
	NF fnum;
} _kind_3;
	struct {
	NIM_BOOL bval;
} _kind_4;
	struct {
	tyObject_OrderedTable__ASIVNBCKpz8qGZwzYCCBFQ fields;
} _kind_6;
	struct {
	tySequence__fXWXs2NlFKREhy9cn6vokJw elems;
} _kind_7;
};
};
struct tySequence__4eQHGndY6XBYpFOH09apV8Q {
  NI len; tySequence__4eQHGndY6XBYpFOH09apV8Q_Content* p;
};
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ {
  NI len; tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content* p;
};
struct tyObject_BuildCache__lwHTcYFYjgY7FbhZRiNECA {
	NimStringV2 cacheVersion;
	NimStringV2 outputFile;
	NimStringV2 outputLastModificationTime;
	tySequence__4eQHGndY6XBYpFOH09apV8Q compile;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ link;
	NimStringV2 linkcmd;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ extraCmds;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ configFiles;
	NIM_BOOL stdinInput;
	NIM_BOOL projectIsCmd;
	NimStringV2 cmdInput;
	NimStringV2 currentDir;
	NimStringV2 cmdline;
	tySequence__4eQHGndY6XBYpFOH09apV8Q depfiles;
	NimStringV2 nimexe;
};
typedef NimStringV2 tyArray__dyW7vpmfeTYw8kX3EXuaJA[3];
struct tyTuple__UV3llMMYFckfui8YMBuUZA {
	NimStringV2 Field0;
	NimStringV2 Field1;
};
typedef NimStringV2 tyArray__Seu7uK9aaOSN0BK3EAjjSHw[4];
typedef NU8 tyEnum_EnumMode__KZXs5DJfkxxPYeMdTIagsQ;
typedef NU8 tyEnum_JsonNodeMode__HNL4GECPp7laf54R6Sl6LA;
struct tyObject_ToJsonOptions__xxRei9adCn4x50jeG886fag {
	tyEnum_EnumMode__KZXs5DJfkxxPYeMdTIagsQ enumMode;
	tyEnum_JsonNodeMode__HNL4GECPp7laf54R6Sl6LA jsonNodeMode;
};
struct tyObject_StackTraceEntry__RcJz5RXFIYjIseutvVFICA {
	NCSTRING procname;
	NI line;
	NCSTRING filename;
};
struct tySequence__S89cE01OvNjsN9c71FKsSrqQ_Content { NI cap; tyObject_StackTraceEntry__RcJz5RXFIYjIseutvVFICA data[SEQ_DECL_SIZE]; };
struct tyTuple__eR5B9b9c9coYBbO09chTvuMqNQ {
	NI Field0;
	NI Field1;
	NimStringV2 Field2;
	tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* Field3;
};
struct tySequence__m9axZwxFfhSNLcoofvKZJYA_Content { NI cap; tyTuple__eR5B9b9c9coYBbO09chTvuMqNQ data[SEQ_DECL_SIZE]; };
struct tySequence__fXWXs2NlFKREhy9cn6vokJw_Content { NI cap; tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* data[SEQ_DECL_SIZE]; };
struct tySequence__4eQHGndY6XBYpFOH09apV8Q_Content { NI cap; tyTuple__UV3llMMYFckfui8YMBuUZA data[SEQ_DECL_SIZE]; };
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content { NI cap; NimStringV2 data[SEQ_DECL_SIZE]; };
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, eqeq___pureZjson_u2433)(tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* a_p0, tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* b_p1);
N_LIB_PRIVATE N_NOINLINE(void, raiseJsonException__stdZjsonutils_u191)(NimStringV2 condStr_p0, NimStringV2 msg_p1);
N_LIB_PRIVATE N_NIMCALL(void*, nimNewObj)(NI size_p0, NI alignment_p1);
static N_INLINE(void, appendString)(NimStringV2* dest_p0, NimStringV2 src_p1);
static N_INLINE(void, copyMem__system_u1742)(void* dest_p0, void* source_p1, NI size_p2);
static N_INLINE(void, nimCopyMem)(void* dest_p0, void* source_p1, NI size_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, rawNewString)(NI space_p0);
N_LIB_PRIVATE N_NIMCALL(void, raiseExceptionEx)(Exception* e_p0, NCSTRING ename_p1, NCSTRING procname_p2, NCSTRING filename_p3, NI line_p4);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___stdZjsonutils_u447)(tyTuple__M7ImznM2hk9a9beBDTxcwGeg x_p0);
static N_INLINE(void, nimZeroMem)(void* p_p0, NI size_p1);
static N_INLINE(void, nimSetMem__system_u2172)(void* a_p0, int v_p1, NI size_p2);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___system_u2691)(NimStringV2 dest_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___pureZjson_u23)(tyEnum_JsonNodeKind__qvXp5fGPKV9a8zGGwjrKjDA e_p0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasKey__pureZjson_u3583)(tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* node_p0, NimStringV2 key_p1);
N_LIB_PRIVATE N_NIMCALL(void, fromJson__stdZjsonutils_u575)(NimStringV2* a_p0, tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* b_p1, tyObject_Joptions__sSnirGarU4zL21BjW4JcHQ opt_p2);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___system_u2700)(NimStringV2* dest_p0, NimStringV2 src_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, to__stdZjsonutils_u591)(tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* node_p0);
static N_INLINE(NIM_BOOL*, nimErrorFlag)(void);
static N_INLINE(tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g*, X5BX5D___pureZjson_u3478)(tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* node_p0, NimStringV2 name_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___pureZjson_u327)(tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g** dest_p0, tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* src_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g**, X5BX5D___pureZjson_u3048)(tyObject_OrderedTable__ASIVNBCKpz8qGZwzYCCBFQ* t_p0, NimStringV2 key_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___pureZjson_u324)(tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* dest_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___extccomp_u2488)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, pretty__pureZjson_u4827)(tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* node_p0, NI indent_p1);
N_LIB_PRIVATE N_NIMCALL(void, fromJson__extccomp_u2561)(tySequence__4eQHGndY6XBYpFOH09apV8Q* a_p0, tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* b_p1, tyObject_Joptions__sSnirGarU4zL21BjW4JcHQ opt_p2);
N_LIB_PRIVATE N_NIMCALL(void, setLen__extccomp_u1953)(tySequence__4eQHGndY6XBYpFOH09apV8Q* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(NI, len__pureZjson_u3428)(tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* n_p0);
N_LIB_PRIVATE N_NIMCALL(tySequence__fXWXs2NlFKREhy9cn6vokJw, getElems__pureZjson_u647)(tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* n_p0, tySequence__fXWXs2NlFKREhy9cn6vokJw default_p1);
N_LIB_PRIVATE N_NIMCALL(void*, newSeqPayload)(NI cap_p0, NI elemSize_p1, NI elemAlign_p2);
N_LIB_PRIVATE N_NIMCALL(void, fromJson__extccomp_u2632)(tyTuple__UV3llMMYFckfui8YMBuUZA* a_p0, tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* b_p1, tyObject_Joptions__sSnirGarU4zL21BjW4JcHQ opt_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___systemZdollars_u9)(NI xX60gensym0__p0);
static N_INLINE(tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g*, X5BX5D___pureZjson_u3549)(tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* node_p0, NI index_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___pureZjson_u257)(tySequence__fXWXs2NlFKREhy9cn6vokJw dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, fromJson__extccomp_u2718)(tySequence__sM4lkSb7zS6F7OVMvW9cffQ* a_p0, tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* b_p1, tyObject_Joptions__sSnirGarU4zL21BjW4JcHQ opt_p2);
N_LIB_PRIVATE N_NIMCALL(void, setLen__system_u5410)(tySequence__sM4lkSb7zS6F7OVMvW9cffQ* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, fromJson__extccomp_u2855)(NIM_BOOL* a_p0, tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* b_p1, tyObject_Joptions__sSnirGarU4zL21BjW4JcHQ opt_p2);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, to__extccomp_u2867)(tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* node_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___extccomp_u3055)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g*, newJObject__pureZjson_u443)(void);
static N_INLINE(void, X5BX5Deq___pureZjson_u2308)(tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* obj_p0, NimStringV2 key_p1, tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* val_p2);
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___pureZjson_u739)(tyObject_OrderedTable__ASIVNBCKpz8qGZwzYCCBFQ* t_p0, NimStringV2 key_p1, tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* val_p2);
N_LIB_PRIVATE N_NIMCALL(tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g*, eqdup___pureZjson_u330)(tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* src_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g*, toJson__stdZjsonutils_u628)(NimStringV2 a_p0, tyObject_ToJsonOptions__xxRei9adCn4x50jeG886fag opt_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g*, percent___pureZjson_u2158)(NimStringV2 s_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g*, toJson__extccomp_u2205)(tySequence__4eQHGndY6XBYpFOH09apV8Q a_p0, tyObject_ToJsonOptions__xxRei9adCn4x50jeG886fag opt_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g*, newJArray__pureZjson_u506)(void);
N_LIB_PRIVATE N_NIMCALL(void, add__pureZjson_u662)(tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* father_p0, tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* child_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g*, toJson__extccomp_u2233)(tyTuple__UV3llMMYFckfui8YMBuUZA* a_p0, tyObject_ToJsonOptions__xxRei9adCn4x50jeG886fag opt_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g*, toJson__extccomp_u2254)(tySequence__sM4lkSb7zS6F7OVMvW9cffQ a_p0, tyObject_ToJsonOptions__xxRei9adCn4x50jeG886fag opt_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g*, toJson__extccomp_u2282)(NIM_BOOL a_p0, tyObject_ToJsonOptions__xxRei9adCn4x50jeG886fag opt_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g*, percent___pureZjson_u2184)(NIM_BOOL b_p0);
extern TNimTypeV2 NTIv2__S29bKZF4TUS33IR7ZXb7fFA_;
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__D9aPSI6l3gZsoFvdx9c3FKBg_2 = { 9 | NIM_STRLIT_FLAG, " failed: " };
static const NimStringV2 TM__D9aPSI6l3gZsoFvdx9c3FKBg_3 = {9, (NimStrPayload*)&TM__D9aPSI6l3gZsoFvdx9c3FKBg_2};
static const struct {
  NI cap; NIM_CHAR data[15+1];
} TM__D9aPSI6l3gZsoFvdx9c3FKBg_4 = { 15 | NIM_STRLIT_FLAG, "\012not (b == nil)" };
static const NimStringV2 TM__D9aPSI6l3gZsoFvdx9c3FKBg_5 = {15, (NimStrPayload*)&TM__D9aPSI6l3gZsoFvdx9c3FKBg_4};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__D9aPSI6l3gZsoFvdx9c3FKBg_6 = { 10 | NIM_STRLIT_FLAG, "BuildCache" };
static const NimStringV2 TM__D9aPSI6l3gZsoFvdx9c3FKBg_7 = {10, (NimStrPayload*)&TM__D9aPSI6l3gZsoFvdx9c3FKBg_6};
static const struct {
  NI cap; NIM_CHAR data[17+1];
} TM__D9aPSI6l3gZsoFvdx9c3FKBg_8 = { 17 | NIM_STRLIT_FLAG, "b.kind == JObject" };
static const NimStringV2 TM__D9aPSI6l3gZsoFvdx9c3FKBg_9 = {17, (NimStrPayload*)&TM__D9aPSI6l3gZsoFvdx9c3FKBg_8};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__D9aPSI6l3gZsoFvdx9c3FKBg_10 = { 12 | NIM_STRLIT_FLAG, "cacheVersion" };
static const NimStringV2 TM__D9aPSI6l3gZsoFvdx9c3FKBg_11 = {12, (NimStrPayload*)&TM__D9aPSI6l3gZsoFvdx9c3FKBg_10};
static const NimStringV2 TM__D9aPSI6l3gZsoFvdx9c3FKBg_12 = {15, (NimStrPayload*)&TM__D9aPSI6l3gZsoFvdx9c3FKBg_4};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__D9aPSI6l3gZsoFvdx9c3FKBg_13 = { 6 | NIM_STRLIT_FLAG, "string" };
static const NimStringV2 TM__D9aPSI6l3gZsoFvdx9c3FKBg_14 = {6, (NimStrPayload*)&TM__D9aPSI6l3gZsoFvdx9c3FKBg_13};
static const NimStringV2 TM__D9aPSI6l3gZsoFvdx9c3FKBg_15 = {12, (NimStrPayload*)&TM__D9aPSI6l3gZsoFvdx9c3FKBg_10};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__D9aPSI6l3gZsoFvdx9c3FKBg_16 = { 5 | NIM_STRLIT_FLAG, "false" };
static const NimStringV2 TM__D9aPSI6l3gZsoFvdx9c3FKBg_17 = {5, (NimStrPayload*)&TM__D9aPSI6l3gZsoFvdx9c3FKBg_16};
static const NimStringV2 TM__D9aPSI6l3gZsoFvdx9c3FKBg_18 = {12, (NimStrPayload*)&TM__D9aPSI6l3gZsoFvdx9c3FKBg_10};
static const NimStringV2 TM__D9aPSI6l3gZsoFvdx9c3FKBg_19 = {10, (NimStrPayload*)&TM__D9aPSI6l3gZsoFvdx9c3FKBg_6};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__D9aPSI6l3gZsoFvdx9c3FKBg_20 = { 10 | NIM_STRLIT_FLAG, "outputFile" };
static const NimStringV2 TM__D9aPSI6l3gZsoFvdx9c3FKBg_21 = {10, (NimStrPayload*)&TM__D9aPSI6l3gZsoFvdx9c3FKBg_20};
static const NimStringV2 TM__D9aPSI6l3gZsoFvdx9c3FKBg_22 = {10, (NimStrPayload*)&TM__D9aPSI6l3gZsoFvdx9c3FKBg_20};
static const NimStringV2 TM__D9aPSI6l3gZsoFvdx9c3FKBg_23 = {5, (NimStrPayload*)&TM__D9aPSI6l3gZsoFvdx9c3FKBg_16};
static const NimStringV2 TM__D9aPSI6l3gZsoFvdx9c3FKBg_24 = {10, (NimStrPayload*)&TM__D9aPSI6l3gZsoFvdx9c3FKBg_20};
static const NimStringV2 TM__D9aPSI6l3gZsoFvdx9c3FKBg_25 = {10, (NimStrPayload*)&TM__D9aPSI6l3gZsoFvdx9c3FKBg_6};
static const struct {
  NI cap; NIM_CHAR data[26+1];
} TM__D9aPSI6l3gZsoFvdx9c3FKBg_26 = { 26 | NIM_STRLIT_FLAG, "outputLastModificationTime" };
static const NimStringV2 TM__D9aPSI6l3gZsoFvdx9c3FKBg_27 = {26, (NimStrPayload*)&TM__D9aPSI6l3gZsoFvdx9c3FKBg_26};
static const NimStringV2 TM__D9aPSI6l3gZsoFvdx9c3FKBg_28 = {26, (NimStrPayload*)&TM__D9aPSI6l3gZsoFvdx9c3FKBg_26};
static const NimStringV2 TM__D9aPSI6l3gZsoFvdx9c3FKBg_29 = {5, (NimStrPayload*)&TM__D9aPSI6l3gZsoFvdx9c3FKBg_16};
static const NimStringV2 TM__D9aPSI6l3gZsoFvdx9c3FKBg_30 = {26, (NimStrPayload*)&TM__D9aPSI6l3gZsoFvdx9c3FKBg_26};
static const NimStringV2 TM__D9aPSI6l3gZsoFvdx9c3FKBg_31 = {10, (NimStrPayload*)&TM__D9aPSI6l3gZsoFvdx9c3FKBg_6};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__D9aPSI6l3gZsoFvdx9c3FKBg_32 = { 7 | NIM_STRLIT_FLAG, "compile" };
static const NimStringV2 TM__D9aPSI6l3gZsoFvdx9c3FKBg_33 = {7, (NimStrPayload*)&TM__D9aPSI6l3gZsoFvdx9c3FKBg_32};
static const NimStringV2 TM__D9aPSI6l3gZsoFvdx9c3FKBg_34 = {15, (NimStrPayload*)&TM__D9aPSI6l3gZsoFvdx9c3FKBg_4};
static const struct {
  NI cap; NIM_CHAR data[21+1];
} TM__D9aPSI6l3gZsoFvdx9c3FKBg_35 = { 21 | NIM_STRLIT_FLAG, "seq[(string, string)]" };
static const NimStringV2 TM__D9aPSI6l3gZsoFvdx9c3FKBg_36 = {21, (NimStrPayload*)&TM__D9aPSI6l3gZsoFvdx9c3FKBg_35};
static const NimStringV2 TM__D9aPSI6l3gZsoFvdx9c3FKBg_37 = {15, (NimStrPayload*)&TM__D9aPSI6l3gZsoFvdx9c3FKBg_4};
static const struct {
  NI cap; NIM_CHAR data[16+1];
} TM__D9aPSI6l3gZsoFvdx9c3FKBg_38 = { 16 | NIM_STRLIT_FLAG, "(string, string)" };
static const NimStringV2 TM__D9aPSI6l3gZsoFvdx9c3FKBg_39 = {16, (NimStrPayload*)&TM__D9aPSI6l3gZsoFvdx9c3FKBg_38};
static const struct {
  NI cap; NIM_CHAR data[16+1];
} TM__D9aPSI6l3gZsoFvdx9c3FKBg_40 = { 16 | NIM_STRLIT_FLAG, "b.kind == JArray" };
static const NimStringV2 TM__D9aPSI6l3gZsoFvdx9c3FKBg_41 = {16, (NimStrPayload*)&TM__D9aPSI6l3gZsoFvdx9c3FKBg_40};
static const struct {
  NI cap; NIM_CHAR data[18+1];
} TM__D9aPSI6l3gZsoFvdx9c3FKBg_42 = { 18 | NIM_STRLIT_FLAG, "b.len == tupleSize" };
static const NimStringV2 TM__D9aPSI6l3gZsoFvdx9c3FKBg_43 = {18, (NimStrPayload*)&TM__D9aPSI6l3gZsoFvdx9c3FKBg_42};
static const struct {
  NI cap; NIM_CHAR data[38+1];
} TM__D9aPSI6l3gZsoFvdx9c3FKBg_44 = { 38 | NIM_STRLIT_FLAG, "Json doesn\'t match expected length of " };
static const NimStringV2 TM__D9aPSI6l3gZsoFvdx9c3FKBg_45 = {38, (NimStrPayload*)&TM__D9aPSI6l3gZsoFvdx9c3FKBg_44};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__D9aPSI6l3gZsoFvdx9c3FKBg_46 = { 6 | NIM_STRLIT_FLAG, ", got " };
static const NimStringV2 TM__D9aPSI6l3gZsoFvdx9c3FKBg_47 = {6, (NimStrPayload*)&TM__D9aPSI6l3gZsoFvdx9c3FKBg_46};
static const NimStringV2 TM__D9aPSI6l3gZsoFvdx9c3FKBg_48 = {7, (NimStrPayload*)&TM__D9aPSI6l3gZsoFvdx9c3FKBg_32};
static const NimStringV2 TM__D9aPSI6l3gZsoFvdx9c3FKBg_49 = {5, (NimStrPayload*)&TM__D9aPSI6l3gZsoFvdx9c3FKBg_16};
static const NimStringV2 TM__D9aPSI6l3gZsoFvdx9c3FKBg_50 = {7, (NimStrPayload*)&TM__D9aPSI6l3gZsoFvdx9c3FKBg_32};
static const NimStringV2 TM__D9aPSI6l3gZsoFvdx9c3FKBg_51 = {10, (NimStrPayload*)&TM__D9aPSI6l3gZsoFvdx9c3FKBg_6};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__D9aPSI6l3gZsoFvdx9c3FKBg_52 = { 4 | NIM_STRLIT_FLAG, "link" };
static const NimStringV2 TM__D9aPSI6l3gZsoFvdx9c3FKBg_53 = {4, (NimStrPayload*)&TM__D9aPSI6l3gZsoFvdx9c3FKBg_52};
static const NimStringV2 TM__D9aPSI6l3gZsoFvdx9c3FKBg_54 = {15, (NimStrPayload*)&TM__D9aPSI6l3gZsoFvdx9c3FKBg_4};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__D9aPSI6l3gZsoFvdx9c3FKBg_55 = { 11 | NIM_STRLIT_FLAG, "seq[string]" };
static const NimStringV2 TM__D9aPSI6l3gZsoFvdx9c3FKBg_56 = {11, (NimStrPayload*)&TM__D9aPSI6l3gZsoFvdx9c3FKBg_55};
static const NimStringV2 TM__D9aPSI6l3gZsoFvdx9c3FKBg_57 = {4, (NimStrPayload*)&TM__D9aPSI6l3gZsoFvdx9c3FKBg_52};
static const NimStringV2 TM__D9aPSI6l3gZsoFvdx9c3FKBg_58 = {5, (NimStrPayload*)&TM__D9aPSI6l3gZsoFvdx9c3FKBg_16};
static const NimStringV2 TM__D9aPSI6l3gZsoFvdx9c3FKBg_59 = {4, (NimStrPayload*)&TM__D9aPSI6l3gZsoFvdx9c3FKBg_52};
static const NimStringV2 TM__D9aPSI6l3gZsoFvdx9c3FKBg_60 = {10, (NimStrPayload*)&TM__D9aPSI6l3gZsoFvdx9c3FKBg_6};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__D9aPSI6l3gZsoFvdx9c3FKBg_61 = { 7 | NIM_STRLIT_FLAG, "linkcmd" };
static const NimStringV2 TM__D9aPSI6l3gZsoFvdx9c3FKBg_62 = {7, (NimStrPayload*)&TM__D9aPSI6l3gZsoFvdx9c3FKBg_61};
static const NimStringV2 TM__D9aPSI6l3gZsoFvdx9c3FKBg_63 = {7, (NimStrPayload*)&TM__D9aPSI6l3gZsoFvdx9c3FKBg_61};
static const NimStringV2 TM__D9aPSI6l3gZsoFvdx9c3FKBg_64 = {5, (NimStrPayload*)&TM__D9aPSI6l3gZsoFvdx9c3FKBg_16};
static const NimStringV2 TM__D9aPSI6l3gZsoFvdx9c3FKBg_65 = {7, (NimStrPayload*)&TM__D9aPSI6l3gZsoFvdx9c3FKBg_61};
static const NimStringV2 TM__D9aPSI6l3gZsoFvdx9c3FKBg_66 = {10, (NimStrPayload*)&TM__D9aPSI6l3gZsoFvdx9c3FKBg_6};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__D9aPSI6l3gZsoFvdx9c3FKBg_67 = { 9 | NIM_STRLIT_FLAG, "extraCmds" };
static const NimStringV2 TM__D9aPSI6l3gZsoFvdx9c3FKBg_68 = {9, (NimStrPayload*)&TM__D9aPSI6l3gZsoFvdx9c3FKBg_67};
static const NimStringV2 TM__D9aPSI6l3gZsoFvdx9c3FKBg_69 = {9, (NimStrPayload*)&TM__D9aPSI6l3gZsoFvdx9c3FKBg_67};
static const NimStringV2 TM__D9aPSI6l3gZsoFvdx9c3FKBg_70 = {5, (NimStrPayload*)&TM__D9aPSI6l3gZsoFvdx9c3FKBg_16};
static const NimStringV2 TM__D9aPSI6l3gZsoFvdx9c3FKBg_71 = {9, (NimStrPayload*)&TM__D9aPSI6l3gZsoFvdx9c3FKBg_67};
static const NimStringV2 TM__D9aPSI6l3gZsoFvdx9c3FKBg_72 = {10, (NimStrPayload*)&TM__D9aPSI6l3gZsoFvdx9c3FKBg_6};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__D9aPSI6l3gZsoFvdx9c3FKBg_73 = { 11 | NIM_STRLIT_FLAG, "configFiles" };
static const NimStringV2 TM__D9aPSI6l3gZsoFvdx9c3FKBg_74 = {11, (NimStrPayload*)&TM__D9aPSI6l3gZsoFvdx9c3FKBg_73};
static const NimStringV2 TM__D9aPSI6l3gZsoFvdx9c3FKBg_75 = {11, (NimStrPayload*)&TM__D9aPSI6l3gZsoFvdx9c3FKBg_73};
static const NimStringV2 TM__D9aPSI6l3gZsoFvdx9c3FKBg_76 = {5, (NimStrPayload*)&TM__D9aPSI6l3gZsoFvdx9c3FKBg_16};
static const NimStringV2 TM__D9aPSI6l3gZsoFvdx9c3FKBg_77 = {11, (NimStrPayload*)&TM__D9aPSI6l3gZsoFvdx9c3FKBg_73};
static const NimStringV2 TM__D9aPSI6l3gZsoFvdx9c3FKBg_78 = {10, (NimStrPayload*)&TM__D9aPSI6l3gZsoFvdx9c3FKBg_6};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__D9aPSI6l3gZsoFvdx9c3FKBg_79 = { 10 | NIM_STRLIT_FLAG, "stdinInput" };
static const NimStringV2 TM__D9aPSI6l3gZsoFvdx9c3FKBg_80 = {10, (NimStrPayload*)&TM__D9aPSI6l3gZsoFvdx9c3FKBg_79};
static const NimStringV2 TM__D9aPSI6l3gZsoFvdx9c3FKBg_81 = {15, (NimStrPayload*)&TM__D9aPSI6l3gZsoFvdx9c3FKBg_4};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__D9aPSI6l3gZsoFvdx9c3FKBg_82 = { 4 | NIM_STRLIT_FLAG, "bool" };
static const NimStringV2 TM__D9aPSI6l3gZsoFvdx9c3FKBg_83 = {4, (NimStrPayload*)&TM__D9aPSI6l3gZsoFvdx9c3FKBg_82};
static const NimStringV2 TM__D9aPSI6l3gZsoFvdx9c3FKBg_84 = {10, (NimStrPayload*)&TM__D9aPSI6l3gZsoFvdx9c3FKBg_79};
static const NimStringV2 TM__D9aPSI6l3gZsoFvdx9c3FKBg_85 = {5, (NimStrPayload*)&TM__D9aPSI6l3gZsoFvdx9c3FKBg_16};
static const NimStringV2 TM__D9aPSI6l3gZsoFvdx9c3FKBg_86 = {10, (NimStrPayload*)&TM__D9aPSI6l3gZsoFvdx9c3FKBg_79};
static const NimStringV2 TM__D9aPSI6l3gZsoFvdx9c3FKBg_87 = {10, (NimStrPayload*)&TM__D9aPSI6l3gZsoFvdx9c3FKBg_6};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__D9aPSI6l3gZsoFvdx9c3FKBg_88 = { 12 | NIM_STRLIT_FLAG, "projectIsCmd" };
static const NimStringV2 TM__D9aPSI6l3gZsoFvdx9c3FKBg_89 = {12, (NimStrPayload*)&TM__D9aPSI6l3gZsoFvdx9c3FKBg_88};
static const NimStringV2 TM__D9aPSI6l3gZsoFvdx9c3FKBg_90 = {12, (NimStrPayload*)&TM__D9aPSI6l3gZsoFvdx9c3FKBg_88};
static const NimStringV2 TM__D9aPSI6l3gZsoFvdx9c3FKBg_91 = {5, (NimStrPayload*)&TM__D9aPSI6l3gZsoFvdx9c3FKBg_16};
static const NimStringV2 TM__D9aPSI6l3gZsoFvdx9c3FKBg_92 = {12, (NimStrPayload*)&TM__D9aPSI6l3gZsoFvdx9c3FKBg_88};
static const NimStringV2 TM__D9aPSI6l3gZsoFvdx9c3FKBg_93 = {10, (NimStrPayload*)&TM__D9aPSI6l3gZsoFvdx9c3FKBg_6};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__D9aPSI6l3gZsoFvdx9c3FKBg_94 = { 8 | NIM_STRLIT_FLAG, "cmdInput" };
static const NimStringV2 TM__D9aPSI6l3gZsoFvdx9c3FKBg_95 = {8, (NimStrPayload*)&TM__D9aPSI6l3gZsoFvdx9c3FKBg_94};
static const NimStringV2 TM__D9aPSI6l3gZsoFvdx9c3FKBg_96 = {8, (NimStrPayload*)&TM__D9aPSI6l3gZsoFvdx9c3FKBg_94};
static const NimStringV2 TM__D9aPSI6l3gZsoFvdx9c3FKBg_97 = {5, (NimStrPayload*)&TM__D9aPSI6l3gZsoFvdx9c3FKBg_16};
static const NimStringV2 TM__D9aPSI6l3gZsoFvdx9c3FKBg_98 = {8, (NimStrPayload*)&TM__D9aPSI6l3gZsoFvdx9c3FKBg_94};
static const NimStringV2 TM__D9aPSI6l3gZsoFvdx9c3FKBg_99 = {10, (NimStrPayload*)&TM__D9aPSI6l3gZsoFvdx9c3FKBg_6};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__D9aPSI6l3gZsoFvdx9c3FKBg_100 = { 10 | NIM_STRLIT_FLAG, "currentDir" };
static const NimStringV2 TM__D9aPSI6l3gZsoFvdx9c3FKBg_101 = {10, (NimStrPayload*)&TM__D9aPSI6l3gZsoFvdx9c3FKBg_100};
static const NimStringV2 TM__D9aPSI6l3gZsoFvdx9c3FKBg_102 = {10, (NimStrPayload*)&TM__D9aPSI6l3gZsoFvdx9c3FKBg_100};
static const NimStringV2 TM__D9aPSI6l3gZsoFvdx9c3FKBg_103 = {5, (NimStrPayload*)&TM__D9aPSI6l3gZsoFvdx9c3FKBg_16};
static const NimStringV2 TM__D9aPSI6l3gZsoFvdx9c3FKBg_104 = {10, (NimStrPayload*)&TM__D9aPSI6l3gZsoFvdx9c3FKBg_100};
static const NimStringV2 TM__D9aPSI6l3gZsoFvdx9c3FKBg_105 = {10, (NimStrPayload*)&TM__D9aPSI6l3gZsoFvdx9c3FKBg_6};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__D9aPSI6l3gZsoFvdx9c3FKBg_106 = { 7 | NIM_STRLIT_FLAG, "cmdline" };
static const NimStringV2 TM__D9aPSI6l3gZsoFvdx9c3FKBg_107 = {7, (NimStrPayload*)&TM__D9aPSI6l3gZsoFvdx9c3FKBg_106};
static const NimStringV2 TM__D9aPSI6l3gZsoFvdx9c3FKBg_108 = {7, (NimStrPayload*)&TM__D9aPSI6l3gZsoFvdx9c3FKBg_106};
static const NimStringV2 TM__D9aPSI6l3gZsoFvdx9c3FKBg_109 = {5, (NimStrPayload*)&TM__D9aPSI6l3gZsoFvdx9c3FKBg_16};
static const NimStringV2 TM__D9aPSI6l3gZsoFvdx9c3FKBg_110 = {7, (NimStrPayload*)&TM__D9aPSI6l3gZsoFvdx9c3FKBg_106};
static const NimStringV2 TM__D9aPSI6l3gZsoFvdx9c3FKBg_111 = {10, (NimStrPayload*)&TM__D9aPSI6l3gZsoFvdx9c3FKBg_6};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__D9aPSI6l3gZsoFvdx9c3FKBg_112 = { 8 | NIM_STRLIT_FLAG, "depfiles" };
static const NimStringV2 TM__D9aPSI6l3gZsoFvdx9c3FKBg_113 = {8, (NimStrPayload*)&TM__D9aPSI6l3gZsoFvdx9c3FKBg_112};
static const NimStringV2 TM__D9aPSI6l3gZsoFvdx9c3FKBg_114 = {8, (NimStrPayload*)&TM__D9aPSI6l3gZsoFvdx9c3FKBg_112};
static const NimStringV2 TM__D9aPSI6l3gZsoFvdx9c3FKBg_115 = {5, (NimStrPayload*)&TM__D9aPSI6l3gZsoFvdx9c3FKBg_16};
static const NimStringV2 TM__D9aPSI6l3gZsoFvdx9c3FKBg_116 = {8, (NimStrPayload*)&TM__D9aPSI6l3gZsoFvdx9c3FKBg_112};
static const NimStringV2 TM__D9aPSI6l3gZsoFvdx9c3FKBg_117 = {10, (NimStrPayload*)&TM__D9aPSI6l3gZsoFvdx9c3FKBg_6};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__D9aPSI6l3gZsoFvdx9c3FKBg_118 = { 6 | NIM_STRLIT_FLAG, "nimexe" };
static const NimStringV2 TM__D9aPSI6l3gZsoFvdx9c3FKBg_119 = {6, (NimStrPayload*)&TM__D9aPSI6l3gZsoFvdx9c3FKBg_118};
static const NimStringV2 TM__D9aPSI6l3gZsoFvdx9c3FKBg_120 = {6, (NimStrPayload*)&TM__D9aPSI6l3gZsoFvdx9c3FKBg_118};
static const NimStringV2 TM__D9aPSI6l3gZsoFvdx9c3FKBg_121 = {5, (NimStrPayload*)&TM__D9aPSI6l3gZsoFvdx9c3FKBg_16};
static const NimStringV2 TM__D9aPSI6l3gZsoFvdx9c3FKBg_122 = {6, (NimStrPayload*)&TM__D9aPSI6l3gZsoFvdx9c3FKBg_118};
static const NimStringV2 TM__D9aPSI6l3gZsoFvdx9c3FKBg_123 = {10, (NimStrPayload*)&TM__D9aPSI6l3gZsoFvdx9c3FKBg_6};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__D9aPSI6l3gZsoFvdx9c3FKBg_124 = { 11 | NIM_STRLIT_FLAG, "ok`gensym10" };
static const NimStringV2 TM__D9aPSI6l3gZsoFvdx9c3FKBg_125 = {11, (NimStrPayload*)&TM__D9aPSI6l3gZsoFvdx9c3FKBg_124};
static const NimStringV2 TM__D9aPSI6l3gZsoFvdx9c3FKBg_126 = {10, (NimStrPayload*)&TM__D9aPSI6l3gZsoFvdx9c3FKBg_6};
static const NimStringV2 TM__D9aPSI6l3gZsoFvdx9c3FKBg_127 = {12, (NimStrPayload*)&TM__D9aPSI6l3gZsoFvdx9c3FKBg_10};
static const NimStringV2 TM__D9aPSI6l3gZsoFvdx9c3FKBg_128 = {10, (NimStrPayload*)&TM__D9aPSI6l3gZsoFvdx9c3FKBg_20};
static const NimStringV2 TM__D9aPSI6l3gZsoFvdx9c3FKBg_129 = {26, (NimStrPayload*)&TM__D9aPSI6l3gZsoFvdx9c3FKBg_26};
static const NimStringV2 TM__D9aPSI6l3gZsoFvdx9c3FKBg_130 = {7, (NimStrPayload*)&TM__D9aPSI6l3gZsoFvdx9c3FKBg_32};
static const NimStringV2 TM__D9aPSI6l3gZsoFvdx9c3FKBg_131 = {4, (NimStrPayload*)&TM__D9aPSI6l3gZsoFvdx9c3FKBg_52};
static const NimStringV2 TM__D9aPSI6l3gZsoFvdx9c3FKBg_132 = {7, (NimStrPayload*)&TM__D9aPSI6l3gZsoFvdx9c3FKBg_61};
static const NimStringV2 TM__D9aPSI6l3gZsoFvdx9c3FKBg_133 = {9, (NimStrPayload*)&TM__D9aPSI6l3gZsoFvdx9c3FKBg_67};
static const NimStringV2 TM__D9aPSI6l3gZsoFvdx9c3FKBg_134 = {11, (NimStrPayload*)&TM__D9aPSI6l3gZsoFvdx9c3FKBg_73};
static const NimStringV2 TM__D9aPSI6l3gZsoFvdx9c3FKBg_135 = {10, (NimStrPayload*)&TM__D9aPSI6l3gZsoFvdx9c3FKBg_79};
static const NimStringV2 TM__D9aPSI6l3gZsoFvdx9c3FKBg_136 = {12, (NimStrPayload*)&TM__D9aPSI6l3gZsoFvdx9c3FKBg_88};
static const NimStringV2 TM__D9aPSI6l3gZsoFvdx9c3FKBg_137 = {8, (NimStrPayload*)&TM__D9aPSI6l3gZsoFvdx9c3FKBg_94};
static const NimStringV2 TM__D9aPSI6l3gZsoFvdx9c3FKBg_138 = {10, (NimStrPayload*)&TM__D9aPSI6l3gZsoFvdx9c3FKBg_100};
static const NimStringV2 TM__D9aPSI6l3gZsoFvdx9c3FKBg_139 = {7, (NimStrPayload*)&TM__D9aPSI6l3gZsoFvdx9c3FKBg_106};
static const NimStringV2 TM__D9aPSI6l3gZsoFvdx9c3FKBg_140 = {8, (NimStrPayload*)&TM__D9aPSI6l3gZsoFvdx9c3FKBg_112};
static const NimStringV2 TM__D9aPSI6l3gZsoFvdx9c3FKBg_141 = {6, (NimStrPayload*)&TM__D9aPSI6l3gZsoFvdx9c3FKBg_118};
extern NIM_BOOL nimInErrorMode__system_u4146;
static N_INLINE(void, nimCopyMem)(void* dest_p0, void* source_p1, NI size_p2) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memcpy(dest_p0, source_p1, ((size_t) (size_p2)));
}
static N_INLINE(void, copyMem__system_u1742)(void* dest_p0, void* source_p1, NI size_p2) {
	nimCopyMem(dest_p0, source_p1, size_p2);
}
static N_INLINE(void, appendString)(NimStringV2* dest_p0, NimStringV2 src_p1) {
	{
		if (!(((NI)0) < src_p1.len)) goto LA3_;
		copyMem__system_u1742(((void*) ((&(*(*dest_p0).p).data[(*dest_p0).len]))), ((void*) ((&(*src_p1.p).data[((NI)0)]))), (src_p1.len));
		(*dest_p0).len += src_p1.len;
		(*(*dest_p0).p).data[(*dest_p0).len] = 0;
	}
LA3_: ;
}
N_LIB_PRIVATE N_NOINLINE(void, raiseJsonException__stdZjsonutils_u191)(NimStringV2 condStr_p0, NimStringV2 msg_p1) {
	tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA* T1_;
	NimStringV2 T2_;
{	T1_ = NIM_NIL;
	T1_ = (tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA*) nimNewObj(sizeof(tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA), NIM_ALIGNOF(tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA));
	(*T1_).Sup.Sup.Sup.m_type = (&NTIv2__S29bKZF4TUS33IR7ZXb7fFA_);
	(*T1_).Sup.Sup.name = "ValueError";
	T2_.len = 0; T2_.p = NIM_NIL;
	T2_ = rawNewString(condStr_p0.len + msg_p1.len + 9);
appendString((&T2_), condStr_p0);
appendString((&T2_), TM__D9aPSI6l3gZsoFvdx9c3FKBg_3);
appendString((&T2_), msg_p1);
	(*T1_).Sup.Sup.message = T2_;
	(*T1_).Sup.Sup.parent = ((Exception*) NIM_NIL);
	raiseExceptionEx((Exception*)T1_, "ValueError", "raiseJsonException", "jsonutils.nim", 128);
goto BeforeRet_;
	}BeforeRet_: ;
}
static N_INLINE(void, nimSetMem__system_u2172)(void* a_p0, int v_p1, NI size_p2) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memset(a_p0, v_p1, ((size_t) (size_p2)));
}
static N_INLINE(void, nimZeroMem)(void* p_p0, NI size_p1) {
	nimSetMem__system_u2172(p_p0, ((int)0), size_p1);
}
static N_INLINE(NIM_BOOL*, nimErrorFlag)(void) {
	NIM_BOOL* result;
	result = (&nimInErrorMode__system_u4146);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, fromJson__stdZjsonutils_u575)(NimStringV2* a_p0, tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* b_p1, tyObject_Joptions__sSnirGarU4zL21BjW4JcHQ opt_p2) {
	NimStringV2 T10_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NIM_BOOL T3_;
		NimStringV2 colontmpD_;
		tyTuple__M7ImznM2hk9a9beBDTxcwGeg T7_;
		T3_ = (NIM_BOOL)0;
		T3_ = eqeq___pureZjson_u2433(b_p1, ((tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g*) NIM_NIL));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!(!(T3_))) goto LA4_;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		nimZeroMem((void*)(&T7_), sizeof(tyTuple__M7ImznM2hk9a9beBDTxcwGeg));
		T7_.Field0 = TM__D9aPSI6l3gZsoFvdx9c3FKBg_14;
		T7_.Field1 = b_p1;
		colontmpD_ = dollar___stdZjsonutils_u447(T7_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		raiseJsonException__stdZjsonutils_u191(TM__D9aPSI6l3gZsoFvdx9c3FKBg_12, colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		{
			LA6_:;
		}
		{
			eqdestroy___system_u2691(colontmpD_);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA4_: ;
	T10_.len = 0; T10_.p = NIM_NIL;
	T10_ = to__stdZjsonutils_u591(b_p1);
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T10_); goto BeforeRet_;}
	eqsink___system_u2700((&(*a_p0)), T10_);
	}BeforeRet_: ;
}
static N_INLINE(tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g*, X5BX5D___pureZjson_u3478)(tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* node_p0, NimStringV2 name_p1) {
	tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* result;
	tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g** T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	T1_ = (tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g**)0;
	T1_ = X5BX5D___pureZjson_u3048((&(*node_p0)._kind_6.fields), name_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqcopy___pureZjson_u327(&result, (*T1_));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g*, X5BX5D___pureZjson_u3549)(tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* node_p0, NI index_p1) {
	tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	eqcopy___pureZjson_u327(&result, (*node_p0)._kind_7.elems.p->data[index_p1]);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, fromJson__extccomp_u2632)(tyTuple__UV3llMMYFckfui8YMBuUZA* a_p0, tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* b_p1, tyObject_Joptions__sSnirGarU4zL21BjW4JcHQ opt_p2) {
	NI tupleSize_1;
	NI i_1;
NIM_BOOL oldNimErrFin30_;
NIM_BOOL oldNimErrFin37_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NIM_BOOL T3_;
		NimStringV2 colontmpD_;
		tyTuple__M7ImznM2hk9a9beBDTxcwGeg T7_;
		T3_ = (NIM_BOOL)0;
		T3_ = eqeq___pureZjson_u2433(b_p1, ((tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g*) NIM_NIL));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!(!(T3_))) goto LA4_;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		nimZeroMem((void*)(&T7_), sizeof(tyTuple__M7ImznM2hk9a9beBDTxcwGeg));
		T7_.Field0 = TM__D9aPSI6l3gZsoFvdx9c3FKBg_39;
		T7_.Field1 = b_p1;
		colontmpD_ = dollar___stdZjsonutils_u447(T7_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		raiseJsonException__stdZjsonutils_u191(TM__D9aPSI6l3gZsoFvdx9c3FKBg_37, colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		{
			LA6_:;
		}
		{
			eqdestroy___system_u2691(colontmpD_);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA4_: ;
	{
		NimStringV2 colontmpD__2;
		if (!!(((*b_p1).kind == ((tyEnum_JsonNodeKind__qvXp5fGPKV9a8zGGwjrKjDA)6)))) goto LA12_;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		colontmpD__2 = dollar___pureZjson_u23((*b_p1).kind);
		raiseJsonException__stdZjsonutils_u191(TM__D9aPSI6l3gZsoFvdx9c3FKBg_41, colontmpD__2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
		{
			LA14_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__2);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA12_: ;
	tupleSize_1 = ((NI)2);
	{
		NI T19_;
		NimStringV2 colontmpD__3;
		NimStringV2 colontmpD__4;
		NimStringV2 colontmpD__5;
		NimStringV2 T23_;
		T19_ = (NI)0;
		T19_ = len__pureZjson_u3428(b_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T19_ == tupleSize_1))) goto LA20_;
		colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
		colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
		colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
		T23_.len = 0; T23_.p = NIM_NIL;
		colontmpD__3 = dollar___systemZdollars_u9(tupleSize_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA22_;
		colontmpD__4 = pretty__pureZjson_u4827(b_p1, ((NI)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA22_;
		T23_ = rawNewString(colontmpD__3.len + colontmpD__4.len + 44);
appendString((&T23_), TM__D9aPSI6l3gZsoFvdx9c3FKBg_45);
appendString((&T23_), colontmpD__3);
appendString((&T23_), TM__D9aPSI6l3gZsoFvdx9c3FKBg_47);
appendString((&T23_), colontmpD__4);
		colontmpD__5 = T23_;
		raiseJsonException__stdZjsonutils_u191(TM__D9aPSI6l3gZsoFvdx9c3FKBg_43, colontmpD__5);
		if (NIM_UNLIKELY(*nimErr_)) goto LA22_;
		{
			LA22_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__5);
			eqdestroy___system_u2691(colontmpD__4);
			eqdestroy___system_u2691(colontmpD__3);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA20_: ;
	i_1 = ((NI)0);
	{
		tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* colontmpD__6;
		if (!NIM_TRUE) goto LA28_;
		colontmpD__6 = NIM_NIL;
		colontmpD__6 = X5BX5D___pureZjson_u3549(b_p1, i_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
		fromJson__stdZjsonutils_u575((&(*a_p0).Field0), colontmpD__6, opt_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
		i_1 += ((NI)1);
		{
			LA30_:;
		}
		{
			oldNimErrFin30_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___pureZjson_u324(colontmpD__6);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin30_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA28_: ;
	{
		tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* colontmpD__7;
		if (!NIM_TRUE) goto LA35_;
		colontmpD__7 = NIM_NIL;
		colontmpD__7 = X5BX5D___pureZjson_u3549(b_p1, i_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA37_;
		fromJson__stdZjsonutils_u575((&(*a_p0).Field1), colontmpD__7, opt_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA37_;
		i_1 += ((NI)1);
		{
			LA37_:;
		}
		{
			oldNimErrFin37_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___pureZjson_u324(colontmpD__7);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin37_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA35_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, fromJson__extccomp_u2561)(tySequence__4eQHGndY6XBYpFOH09apV8Q* a_p0, tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* b_p1, tyObject_Joptions__sSnirGarU4zL21BjW4JcHQ opt_p2) {
	NI T10_;
NIM_BOOL oldNimErrFin12_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NIM_BOOL T3_;
		NimStringV2 colontmpD_;
		tyTuple__M7ImznM2hk9a9beBDTxcwGeg T7_;
		T3_ = (NIM_BOOL)0;
		T3_ = eqeq___pureZjson_u2433(b_p1, ((tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g*) NIM_NIL));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!(!(T3_))) goto LA4_;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		nimZeroMem((void*)(&T7_), sizeof(tyTuple__M7ImznM2hk9a9beBDTxcwGeg));
		T7_.Field0 = TM__D9aPSI6l3gZsoFvdx9c3FKBg_36;
		T7_.Field1 = b_p1;
		colontmpD_ = dollar___stdZjsonutils_u447(T7_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		raiseJsonException__stdZjsonutils_u191(TM__D9aPSI6l3gZsoFvdx9c3FKBg_34, colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		{
			LA6_:;
		}
		{
			eqdestroy___system_u2691(colontmpD_);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA4_: ;
	T10_ = (NI)0;
	T10_ = len__pureZjson_u3428(b_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	setLen__extccomp_u1953((&(*a_p0)), (T10_));
	{
		tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* val_1;
		tySequence__fXWXs2NlFKREhy9cn6vokJw colontmp_;
		NI i_1;
		tySequence__fXWXs2NlFKREhy9cn6vokJw T13_;
		NI i_2;
		NI L_1;
		NI T14_;
		val_1 = NIM_NIL;
		colontmp_.len = 0; colontmp_.p = NIM_NIL;
		i_1 = (NI)0;
		T13_.len = 0; T13_.p = NIM_NIL;
		T13_.len = 0; T13_.p = (tySequence__fXWXs2NlFKREhy9cn6vokJw_Content*) newSeqPayload(0, sizeof(tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g*), NIM_ALIGNOF(tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g*));
		colontmp_ = getElems__pureZjson_u647(b_p1, T13_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
		i_2 = ((NI)0);
		T14_ = colontmp_.len;
		L_1 = T14_;
		{
			while (1) {
				if (!(i_2 < L_1)) goto LA16;
				i_1 = i_2;
				eqcopy___pureZjson_u327(&val_1, colontmp_.p->data[i_2]);
				if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
				fromJson__extccomp_u2632((&(*a_p0).p->data[i_1]), val_1, opt_p2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
				i_2 += ((NI)1);
			} LA16: ;
		}
		{
			LA12_:;
		}
		{
			oldNimErrFin12_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___pureZjson_u257(colontmp_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			eqdestroy___pureZjson_u324(val_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin12_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, fromJson__extccomp_u2718)(tySequence__sM4lkSb7zS6F7OVMvW9cffQ* a_p0, tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* b_p1, tyObject_Joptions__sSnirGarU4zL21BjW4JcHQ opt_p2) {
	NI T10_;
NIM_BOOL oldNimErrFin12_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NIM_BOOL T3_;
		NimStringV2 colontmpD_;
		tyTuple__M7ImznM2hk9a9beBDTxcwGeg T7_;
		T3_ = (NIM_BOOL)0;
		T3_ = eqeq___pureZjson_u2433(b_p1, ((tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g*) NIM_NIL));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!(!(T3_))) goto LA4_;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		nimZeroMem((void*)(&T7_), sizeof(tyTuple__M7ImznM2hk9a9beBDTxcwGeg));
		T7_.Field0 = TM__D9aPSI6l3gZsoFvdx9c3FKBg_56;
		T7_.Field1 = b_p1;
		colontmpD_ = dollar___stdZjsonutils_u447(T7_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		raiseJsonException__stdZjsonutils_u191(TM__D9aPSI6l3gZsoFvdx9c3FKBg_54, colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		{
			LA6_:;
		}
		{
			eqdestroy___system_u2691(colontmpD_);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA4_: ;
	T10_ = (NI)0;
	T10_ = len__pureZjson_u3428(b_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	setLen__system_u5410((&(*a_p0)), (T10_));
	{
		tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* val_1;
		tySequence__fXWXs2NlFKREhy9cn6vokJw colontmp_;
		NI i_1;
		tySequence__fXWXs2NlFKREhy9cn6vokJw T13_;
		NI i_2;
		NI L_1;
		NI T14_;
		val_1 = NIM_NIL;
		colontmp_.len = 0; colontmp_.p = NIM_NIL;
		i_1 = (NI)0;
		T13_.len = 0; T13_.p = NIM_NIL;
		T13_.len = 0; T13_.p = (tySequence__fXWXs2NlFKREhy9cn6vokJw_Content*) newSeqPayload(0, sizeof(tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g*), NIM_ALIGNOF(tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g*));
		colontmp_ = getElems__pureZjson_u647(b_p1, T13_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
		i_2 = ((NI)0);
		T14_ = colontmp_.len;
		L_1 = T14_;
		{
			while (1) {
				if (!(i_2 < L_1)) goto LA16;
				i_1 = i_2;
				eqcopy___pureZjson_u327(&val_1, colontmp_.p->data[i_2]);
				if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
				fromJson__stdZjsonutils_u575((&(*a_p0).p->data[i_1]), val_1, opt_p2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
				i_2 += ((NI)1);
			} LA16: ;
		}
		{
			LA12_:;
		}
		{
			oldNimErrFin12_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___pureZjson_u257(colontmp_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			eqdestroy___pureZjson_u324(val_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin12_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, fromJson__extccomp_u2855)(NIM_BOOL* a_p0, tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* b_p1, tyObject_Joptions__sSnirGarU4zL21BjW4JcHQ opt_p2) {
	NIM_BOOL T10_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NIM_BOOL T3_;
		NimStringV2 colontmpD_;
		tyTuple__M7ImznM2hk9a9beBDTxcwGeg T7_;
		T3_ = (NIM_BOOL)0;
		T3_ = eqeq___pureZjson_u2433(b_p1, ((tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g*) NIM_NIL));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!(!(T3_))) goto LA4_;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		nimZeroMem((void*)(&T7_), sizeof(tyTuple__M7ImznM2hk9a9beBDTxcwGeg));
		T7_.Field0 = TM__D9aPSI6l3gZsoFvdx9c3FKBg_83;
		T7_.Field1 = b_p1;
		colontmpD_ = dollar___stdZjsonutils_u447(T7_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		raiseJsonException__stdZjsonutils_u191(TM__D9aPSI6l3gZsoFvdx9c3FKBg_81, colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		{
			LA6_:;
		}
		{
			eqdestroy___system_u2691(colontmpD_);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA4_: ;
	T10_ = (NIM_BOOL)0;
	T10_ = to__extccomp_u2867(b_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*a_p0) = T10_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, fromJson__extccomp_u2409)(tyObject_BuildCache__lwHTcYFYjgY7FbhZRiNECA* a_p0, tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* b_p1, tyObject_Joptions__sSnirGarU4zL21BjW4JcHQ opt_p2) {
	NIM_BOOL colontmpD_;
	NIM_BOOL colontmpD__2;
	NIM_BOOL colontmpD__3;
	NIM_BOOL colontmpD__4;
	NI numX60gensym10__1;
	NI numMatchedX60gensym10__1;
NIM_BOOL oldNimErrFin26_;
NIM_BOOL oldNimErrFin50_;
NIM_BOOL oldNimErrFin74_;
NIM_BOOL oldNimErrFin98_;
NIM_BOOL oldNimErrFin122_;
NIM_BOOL oldNimErrFin146_;
NIM_BOOL oldNimErrFin170_;
NIM_BOOL oldNimErrFin194_;
NIM_BOOL oldNimErrFin218_;
NIM_BOOL oldNimErrFin242_;
NIM_BOOL oldNimErrFin266_;
NIM_BOOL oldNimErrFin290_;
NIM_BOOL oldNimErrFin314_;
NIM_BOOL oldNimErrFin338_;
NIM_BOOL oldNimErrFin362_;
	NIM_BOOL okX60gensym10__1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_ = (NIM_BOOL)0;
	colontmpD__2 = (NIM_BOOL)0;
	colontmpD__3 = (NIM_BOOL)0;
	colontmpD__4 = (NIM_BOOL)0;
	{
		NIM_BOOL T3_;
		NimStringV2 colontmpD__5;
		tyTuple__M7ImznM2hk9a9beBDTxcwGeg T7_;
		T3_ = (NIM_BOOL)0;
		T3_ = eqeq___pureZjson_u2433(b_p1, ((tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g*) NIM_NIL));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!(!(T3_))) goto LA4_;
		colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
		nimZeroMem((void*)(&T7_), sizeof(tyTuple__M7ImznM2hk9a9beBDTxcwGeg));
		T7_.Field0 = TM__D9aPSI6l3gZsoFvdx9c3FKBg_7;
		T7_.Field1 = b_p1;
		colontmpD__5 = dollar___stdZjsonutils_u447(T7_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		raiseJsonException__stdZjsonutils_u191(TM__D9aPSI6l3gZsoFvdx9c3FKBg_5, colontmpD__5);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		{
			LA6_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__5);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA4_: ;
	{
		NimStringV2 colontmpD__6;
		if (!!(((*b_p1).kind == ((tyEnum_JsonNodeKind__qvXp5fGPKV9a8zGGwjrKjDA)5)))) goto LA12_;
		colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
		colontmpD__6 = dollar___pureZjson_u23((*b_p1).kind);
		raiseJsonException__stdZjsonutils_u191(TM__D9aPSI6l3gZsoFvdx9c3FKBg_9, colontmpD__6);
		if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
		{
			LA14_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__6);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA12_: ;
	numX60gensym10__1 = ((NI)0);
	numMatchedX60gensym10__1 = ((NI)0);
	{
		if (!NIM_TRUE) goto LA19_;
		numX60gensym10__1 += ((NI)1);
		{
			NIM_BOOL T23_;
			tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* colontmpD__7;
			T23_ = (NIM_BOOL)0;
			T23_ = hasKey__pureZjson_u3583(b_p1, TM__D9aPSI6l3gZsoFvdx9c3FKBg_11);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T23_) goto LA24_;
			colontmpD__7 = NIM_NIL;
			numMatchedX60gensym10__1 += ((NI)1);
			colontmpD__7 = X5BX5D___pureZjson_u3478(b_p1, TM__D9aPSI6l3gZsoFvdx9c3FKBg_15);
			if (NIM_UNLIKELY(*nimErr_)) goto LA26_;
			fromJson__stdZjsonutils_u575((&(*a_p0).cacheVersion), colontmpD__7, opt_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA26_;
			{
				LA26_:;
			}
			{
				oldNimErrFin26_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___pureZjson_u324(colontmpD__7);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				*nimErr_ = oldNimErrFin26_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		goto LA21_;
LA24_: ;
		{
			if (!opt_p2.allowMissingKeys) goto LA30_;
		}
		goto LA21_;
LA30_: ;
		{
			{
				NimStringV2 colontmpD__8;
				NimStringV2 colontmpD__9;
				tyArray__dyW7vpmfeTYw8kX3EXuaJA T38_;
				if (!NIM_TRUE) goto LA35_;
				colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
				colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
				T38_[0] = TM__D9aPSI6l3gZsoFvdx9c3FKBg_18;
				T38_[1] = TM__D9aPSI6l3gZsoFvdx9c3FKBg_19;
				colontmpD__8 = pretty__pureZjson_u4827(b_p1, ((NI)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA37_;
				T38_[2] = colontmpD__8;
				colontmpD__9 = percent___extccomp_u2488(T38_, 3);
				if (NIM_UNLIKELY(*nimErr_)) goto LA37_;
				raiseJsonException__stdZjsonutils_u191(TM__D9aPSI6l3gZsoFvdx9c3FKBg_17, colontmpD__9);
				if (NIM_UNLIKELY(*nimErr_)) goto LA37_;
				{
					LA37_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__9);
					eqdestroy___system_u2691(colontmpD__8);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			}
LA35_: ;
		}
LA21_: ;
	}
LA19_: ;
	{
		if (!NIM_TRUE) goto LA43_;
		numX60gensym10__1 += ((NI)1);
		{
			NIM_BOOL T47_;
			tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* colontmpD__10;
			T47_ = (NIM_BOOL)0;
			T47_ = hasKey__pureZjson_u3583(b_p1, TM__D9aPSI6l3gZsoFvdx9c3FKBg_21);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T47_) goto LA48_;
			colontmpD__10 = NIM_NIL;
			numMatchedX60gensym10__1 += ((NI)1);
			colontmpD__10 = X5BX5D___pureZjson_u3478(b_p1, TM__D9aPSI6l3gZsoFvdx9c3FKBg_22);
			if (NIM_UNLIKELY(*nimErr_)) goto LA50_;
			fromJson__stdZjsonutils_u575((&(*a_p0).outputFile), colontmpD__10, opt_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA50_;
			{
				LA50_:;
			}
			{
				oldNimErrFin50_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___pureZjson_u324(colontmpD__10);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				*nimErr_ = oldNimErrFin50_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		goto LA45_;
LA48_: ;
		{
			if (!opt_p2.allowMissingKeys) goto LA54_;
		}
		goto LA45_;
LA54_: ;
		{
			{
				NimStringV2 colontmpD__11;
				NimStringV2 colontmpD__12;
				tyArray__dyW7vpmfeTYw8kX3EXuaJA T62_;
				if (!NIM_TRUE) goto LA59_;
				colontmpD__11.len = 0; colontmpD__11.p = NIM_NIL;
				colontmpD__12.len = 0; colontmpD__12.p = NIM_NIL;
				T62_[0] = TM__D9aPSI6l3gZsoFvdx9c3FKBg_24;
				T62_[1] = TM__D9aPSI6l3gZsoFvdx9c3FKBg_25;
				colontmpD__11 = pretty__pureZjson_u4827(b_p1, ((NI)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA61_;
				T62_[2] = colontmpD__11;
				colontmpD__12 = percent___extccomp_u2488(T62_, 3);
				if (NIM_UNLIKELY(*nimErr_)) goto LA61_;
				raiseJsonException__stdZjsonutils_u191(TM__D9aPSI6l3gZsoFvdx9c3FKBg_23, colontmpD__12);
				if (NIM_UNLIKELY(*nimErr_)) goto LA61_;
				{
					LA61_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__12);
					eqdestroy___system_u2691(colontmpD__11);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			}
LA59_: ;
		}
LA45_: ;
	}
LA43_: ;
	{
		if (!NIM_TRUE) goto LA67_;
		numX60gensym10__1 += ((NI)1);
		{
			NIM_BOOL T71_;
			tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* colontmpD__13;
			T71_ = (NIM_BOOL)0;
			T71_ = hasKey__pureZjson_u3583(b_p1, TM__D9aPSI6l3gZsoFvdx9c3FKBg_27);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T71_) goto LA72_;
			colontmpD__13 = NIM_NIL;
			numMatchedX60gensym10__1 += ((NI)1);
			colontmpD__13 = X5BX5D___pureZjson_u3478(b_p1, TM__D9aPSI6l3gZsoFvdx9c3FKBg_28);
			if (NIM_UNLIKELY(*nimErr_)) goto LA74_;
			fromJson__stdZjsonutils_u575((&(*a_p0).outputLastModificationTime), colontmpD__13, opt_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA74_;
			{
				LA74_:;
			}
			{
				oldNimErrFin74_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___pureZjson_u324(colontmpD__13);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				*nimErr_ = oldNimErrFin74_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		goto LA69_;
LA72_: ;
		{
			if (!opt_p2.allowMissingKeys) goto LA78_;
		}
		goto LA69_;
LA78_: ;
		{
			{
				NimStringV2 colontmpD__14;
				NimStringV2 colontmpD__15;
				tyArray__dyW7vpmfeTYw8kX3EXuaJA T86_;
				if (!NIM_TRUE) goto LA83_;
				colontmpD__14.len = 0; colontmpD__14.p = NIM_NIL;
				colontmpD__15.len = 0; colontmpD__15.p = NIM_NIL;
				T86_[0] = TM__D9aPSI6l3gZsoFvdx9c3FKBg_30;
				T86_[1] = TM__D9aPSI6l3gZsoFvdx9c3FKBg_31;
				colontmpD__14 = pretty__pureZjson_u4827(b_p1, ((NI)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA85_;
				T86_[2] = colontmpD__14;
				colontmpD__15 = percent___extccomp_u2488(T86_, 3);
				if (NIM_UNLIKELY(*nimErr_)) goto LA85_;
				raiseJsonException__stdZjsonutils_u191(TM__D9aPSI6l3gZsoFvdx9c3FKBg_29, colontmpD__15);
				if (NIM_UNLIKELY(*nimErr_)) goto LA85_;
				{
					LA85_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__15);
					eqdestroy___system_u2691(colontmpD__14);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			}
LA83_: ;
		}
LA69_: ;
	}
LA67_: ;
	{
		if (!NIM_TRUE) goto LA91_;
		numX60gensym10__1 += ((NI)1);
		{
			NIM_BOOL T95_;
			tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* colontmpD__16;
			T95_ = (NIM_BOOL)0;
			T95_ = hasKey__pureZjson_u3583(b_p1, TM__D9aPSI6l3gZsoFvdx9c3FKBg_33);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T95_) goto LA96_;
			colontmpD__16 = NIM_NIL;
			numMatchedX60gensym10__1 += ((NI)1);
			colontmpD__16 = X5BX5D___pureZjson_u3478(b_p1, TM__D9aPSI6l3gZsoFvdx9c3FKBg_48);
			if (NIM_UNLIKELY(*nimErr_)) goto LA98_;
			fromJson__extccomp_u2561((&(*a_p0).compile), colontmpD__16, opt_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA98_;
			{
				LA98_:;
			}
			{
				oldNimErrFin98_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___pureZjson_u324(colontmpD__16);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				*nimErr_ = oldNimErrFin98_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		goto LA93_;
LA96_: ;
		{
			if (!opt_p2.allowMissingKeys) goto LA102_;
		}
		goto LA93_;
LA102_: ;
		{
			{
				NimStringV2 colontmpD__17;
				NimStringV2 colontmpD__18;
				tyArray__dyW7vpmfeTYw8kX3EXuaJA T110_;
				if (!NIM_TRUE) goto LA107_;
				colontmpD__17.len = 0; colontmpD__17.p = NIM_NIL;
				colontmpD__18.len = 0; colontmpD__18.p = NIM_NIL;
				T110_[0] = TM__D9aPSI6l3gZsoFvdx9c3FKBg_50;
				T110_[1] = TM__D9aPSI6l3gZsoFvdx9c3FKBg_51;
				colontmpD__17 = pretty__pureZjson_u4827(b_p1, ((NI)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA109_;
				T110_[2] = colontmpD__17;
				colontmpD__18 = percent___extccomp_u2488(T110_, 3);
				if (NIM_UNLIKELY(*nimErr_)) goto LA109_;
				raiseJsonException__stdZjsonutils_u191(TM__D9aPSI6l3gZsoFvdx9c3FKBg_49, colontmpD__18);
				if (NIM_UNLIKELY(*nimErr_)) goto LA109_;
				{
					LA109_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__18);
					eqdestroy___system_u2691(colontmpD__17);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			}
LA107_: ;
		}
LA93_: ;
	}
LA91_: ;
	{
		if (!NIM_TRUE) goto LA115_;
		numX60gensym10__1 += ((NI)1);
		{
			NIM_BOOL T119_;
			tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* colontmpD__19;
			T119_ = (NIM_BOOL)0;
			T119_ = hasKey__pureZjson_u3583(b_p1, TM__D9aPSI6l3gZsoFvdx9c3FKBg_53);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T119_) goto LA120_;
			colontmpD__19 = NIM_NIL;
			numMatchedX60gensym10__1 += ((NI)1);
			colontmpD__19 = X5BX5D___pureZjson_u3478(b_p1, TM__D9aPSI6l3gZsoFvdx9c3FKBg_57);
			if (NIM_UNLIKELY(*nimErr_)) goto LA122_;
			fromJson__extccomp_u2718((&(*a_p0).link), colontmpD__19, opt_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA122_;
			{
				LA122_:;
			}
			{
				oldNimErrFin122_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___pureZjson_u324(colontmpD__19);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				*nimErr_ = oldNimErrFin122_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		goto LA117_;
LA120_: ;
		{
			if (!opt_p2.allowMissingKeys) goto LA126_;
		}
		goto LA117_;
LA126_: ;
		{
			{
				NimStringV2 colontmpD__20;
				NimStringV2 colontmpD__21;
				tyArray__dyW7vpmfeTYw8kX3EXuaJA T134_;
				if (!NIM_TRUE) goto LA131_;
				colontmpD__20.len = 0; colontmpD__20.p = NIM_NIL;
				colontmpD__21.len = 0; colontmpD__21.p = NIM_NIL;
				T134_[0] = TM__D9aPSI6l3gZsoFvdx9c3FKBg_59;
				T134_[1] = TM__D9aPSI6l3gZsoFvdx9c3FKBg_60;
				colontmpD__20 = pretty__pureZjson_u4827(b_p1, ((NI)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA133_;
				T134_[2] = colontmpD__20;
				colontmpD__21 = percent___extccomp_u2488(T134_, 3);
				if (NIM_UNLIKELY(*nimErr_)) goto LA133_;
				raiseJsonException__stdZjsonutils_u191(TM__D9aPSI6l3gZsoFvdx9c3FKBg_58, colontmpD__21);
				if (NIM_UNLIKELY(*nimErr_)) goto LA133_;
				{
					LA133_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__21);
					eqdestroy___system_u2691(colontmpD__20);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			}
LA131_: ;
		}
LA117_: ;
	}
LA115_: ;
	{
		if (!NIM_TRUE) goto LA139_;
		numX60gensym10__1 += ((NI)1);
		{
			NIM_BOOL T143_;
			tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* colontmpD__22;
			T143_ = (NIM_BOOL)0;
			T143_ = hasKey__pureZjson_u3583(b_p1, TM__D9aPSI6l3gZsoFvdx9c3FKBg_62);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T143_) goto LA144_;
			colontmpD__22 = NIM_NIL;
			numMatchedX60gensym10__1 += ((NI)1);
			colontmpD__22 = X5BX5D___pureZjson_u3478(b_p1, TM__D9aPSI6l3gZsoFvdx9c3FKBg_63);
			if (NIM_UNLIKELY(*nimErr_)) goto LA146_;
			fromJson__stdZjsonutils_u575((&(*a_p0).linkcmd), colontmpD__22, opt_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA146_;
			{
				LA146_:;
			}
			{
				oldNimErrFin146_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___pureZjson_u324(colontmpD__22);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				*nimErr_ = oldNimErrFin146_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		goto LA141_;
LA144_: ;
		{
			if (!opt_p2.allowMissingKeys) goto LA150_;
		}
		goto LA141_;
LA150_: ;
		{
			{
				NimStringV2 colontmpD__23;
				NimStringV2 colontmpD__24;
				tyArray__dyW7vpmfeTYw8kX3EXuaJA T158_;
				if (!NIM_TRUE) goto LA155_;
				colontmpD__23.len = 0; colontmpD__23.p = NIM_NIL;
				colontmpD__24.len = 0; colontmpD__24.p = NIM_NIL;
				T158_[0] = TM__D9aPSI6l3gZsoFvdx9c3FKBg_65;
				T158_[1] = TM__D9aPSI6l3gZsoFvdx9c3FKBg_66;
				colontmpD__23 = pretty__pureZjson_u4827(b_p1, ((NI)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA157_;
				T158_[2] = colontmpD__23;
				colontmpD__24 = percent___extccomp_u2488(T158_, 3);
				if (NIM_UNLIKELY(*nimErr_)) goto LA157_;
				raiseJsonException__stdZjsonutils_u191(TM__D9aPSI6l3gZsoFvdx9c3FKBg_64, colontmpD__24);
				if (NIM_UNLIKELY(*nimErr_)) goto LA157_;
				{
					LA157_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__24);
					eqdestroy___system_u2691(colontmpD__23);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			}
LA155_: ;
		}
LA141_: ;
	}
LA139_: ;
	{
		if (!NIM_TRUE) goto LA163_;
		numX60gensym10__1 += ((NI)1);
		{
			NIM_BOOL T167_;
			tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* colontmpD__25;
			T167_ = (NIM_BOOL)0;
			T167_ = hasKey__pureZjson_u3583(b_p1, TM__D9aPSI6l3gZsoFvdx9c3FKBg_68);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T167_) goto LA168_;
			colontmpD__25 = NIM_NIL;
			numMatchedX60gensym10__1 += ((NI)1);
			colontmpD__25 = X5BX5D___pureZjson_u3478(b_p1, TM__D9aPSI6l3gZsoFvdx9c3FKBg_69);
			if (NIM_UNLIKELY(*nimErr_)) goto LA170_;
			fromJson__extccomp_u2718((&(*a_p0).extraCmds), colontmpD__25, opt_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA170_;
			{
				LA170_:;
			}
			{
				oldNimErrFin170_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___pureZjson_u324(colontmpD__25);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				*nimErr_ = oldNimErrFin170_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		goto LA165_;
LA168_: ;
		{
			if (!opt_p2.allowMissingKeys) goto LA174_;
		}
		goto LA165_;
LA174_: ;
		{
			{
				NimStringV2 colontmpD__26;
				NimStringV2 colontmpD__27;
				tyArray__dyW7vpmfeTYw8kX3EXuaJA T182_;
				if (!NIM_TRUE) goto LA179_;
				colontmpD__26.len = 0; colontmpD__26.p = NIM_NIL;
				colontmpD__27.len = 0; colontmpD__27.p = NIM_NIL;
				T182_[0] = TM__D9aPSI6l3gZsoFvdx9c3FKBg_71;
				T182_[1] = TM__D9aPSI6l3gZsoFvdx9c3FKBg_72;
				colontmpD__26 = pretty__pureZjson_u4827(b_p1, ((NI)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA181_;
				T182_[2] = colontmpD__26;
				colontmpD__27 = percent___extccomp_u2488(T182_, 3);
				if (NIM_UNLIKELY(*nimErr_)) goto LA181_;
				raiseJsonException__stdZjsonutils_u191(TM__D9aPSI6l3gZsoFvdx9c3FKBg_70, colontmpD__27);
				if (NIM_UNLIKELY(*nimErr_)) goto LA181_;
				{
					LA181_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__27);
					eqdestroy___system_u2691(colontmpD__26);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			}
LA179_: ;
		}
LA165_: ;
	}
LA163_: ;
	{
		if (!NIM_TRUE) goto LA187_;
		numX60gensym10__1 += ((NI)1);
		{
			NIM_BOOL T191_;
			tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* colontmpD__28;
			T191_ = (NIM_BOOL)0;
			T191_ = hasKey__pureZjson_u3583(b_p1, TM__D9aPSI6l3gZsoFvdx9c3FKBg_74);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T191_) goto LA192_;
			colontmpD__28 = NIM_NIL;
			numMatchedX60gensym10__1 += ((NI)1);
			colontmpD__28 = X5BX5D___pureZjson_u3478(b_p1, TM__D9aPSI6l3gZsoFvdx9c3FKBg_75);
			if (NIM_UNLIKELY(*nimErr_)) goto LA194_;
			fromJson__extccomp_u2718((&(*a_p0).configFiles), colontmpD__28, opt_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA194_;
			{
				LA194_:;
			}
			{
				oldNimErrFin194_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___pureZjson_u324(colontmpD__28);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				*nimErr_ = oldNimErrFin194_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		goto LA189_;
LA192_: ;
		{
			if (!opt_p2.allowMissingKeys) goto LA198_;
		}
		goto LA189_;
LA198_: ;
		{
			{
				NimStringV2 colontmpD__29;
				NimStringV2 colontmpD__30;
				tyArray__dyW7vpmfeTYw8kX3EXuaJA T206_;
				if (!NIM_TRUE) goto LA203_;
				colontmpD__29.len = 0; colontmpD__29.p = NIM_NIL;
				colontmpD__30.len = 0; colontmpD__30.p = NIM_NIL;
				T206_[0] = TM__D9aPSI6l3gZsoFvdx9c3FKBg_77;
				T206_[1] = TM__D9aPSI6l3gZsoFvdx9c3FKBg_78;
				colontmpD__29 = pretty__pureZjson_u4827(b_p1, ((NI)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA205_;
				T206_[2] = colontmpD__29;
				colontmpD__30 = percent___extccomp_u2488(T206_, 3);
				if (NIM_UNLIKELY(*nimErr_)) goto LA205_;
				raiseJsonException__stdZjsonutils_u191(TM__D9aPSI6l3gZsoFvdx9c3FKBg_76, colontmpD__30);
				if (NIM_UNLIKELY(*nimErr_)) goto LA205_;
				{
					LA205_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__30);
					eqdestroy___system_u2691(colontmpD__29);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			}
LA203_: ;
		}
LA189_: ;
	}
LA187_: ;
	{
		if (!NIM_TRUE) goto LA211_;
		numX60gensym10__1 += ((NI)1);
		{
			NIM_BOOL T215_;
			tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* colontmpD__31;
			T215_ = (NIM_BOOL)0;
			T215_ = hasKey__pureZjson_u3583(b_p1, TM__D9aPSI6l3gZsoFvdx9c3FKBg_80);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T215_) goto LA216_;
			colontmpD__31 = NIM_NIL;
			numMatchedX60gensym10__1 += ((NI)1);
			colontmpD__31 = X5BX5D___pureZjson_u3478(b_p1, TM__D9aPSI6l3gZsoFvdx9c3FKBg_84);
			if (NIM_UNLIKELY(*nimErr_)) goto LA218_;
			fromJson__extccomp_u2855((&(*a_p0).stdinInput), colontmpD__31, opt_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA218_;
			{
				LA218_:;
			}
			{
				oldNimErrFin218_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___pureZjson_u324(colontmpD__31);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				*nimErr_ = oldNimErrFin218_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		goto LA213_;
LA216_: ;
		{
			if (!opt_p2.allowMissingKeys) goto LA222_;
		}
		goto LA213_;
LA222_: ;
		{
			{
				NimStringV2 colontmpD__32;
				NimStringV2 colontmpD__33;
				tyArray__dyW7vpmfeTYw8kX3EXuaJA T230_;
				if (!NIM_TRUE) goto LA227_;
				colontmpD__32.len = 0; colontmpD__32.p = NIM_NIL;
				colontmpD__33.len = 0; colontmpD__33.p = NIM_NIL;
				T230_[0] = TM__D9aPSI6l3gZsoFvdx9c3FKBg_86;
				T230_[1] = TM__D9aPSI6l3gZsoFvdx9c3FKBg_87;
				colontmpD__32 = pretty__pureZjson_u4827(b_p1, ((NI)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA229_;
				T230_[2] = colontmpD__32;
				colontmpD__33 = percent___extccomp_u2488(T230_, 3);
				if (NIM_UNLIKELY(*nimErr_)) goto LA229_;
				raiseJsonException__stdZjsonutils_u191(TM__D9aPSI6l3gZsoFvdx9c3FKBg_85, colontmpD__33);
				if (NIM_UNLIKELY(*nimErr_)) goto LA229_;
				{
					LA229_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__33);
					eqdestroy___system_u2691(colontmpD__32);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			}
LA227_: ;
		}
LA213_: ;
	}
LA211_: ;
	{
		if (!NIM_TRUE) goto LA235_;
		numX60gensym10__1 += ((NI)1);
		{
			NIM_BOOL T239_;
			tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* colontmpD__34;
			T239_ = (NIM_BOOL)0;
			T239_ = hasKey__pureZjson_u3583(b_p1, TM__D9aPSI6l3gZsoFvdx9c3FKBg_89);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T239_) goto LA240_;
			colontmpD__34 = NIM_NIL;
			numMatchedX60gensym10__1 += ((NI)1);
			colontmpD__34 = X5BX5D___pureZjson_u3478(b_p1, TM__D9aPSI6l3gZsoFvdx9c3FKBg_90);
			if (NIM_UNLIKELY(*nimErr_)) goto LA242_;
			fromJson__extccomp_u2855((&(*a_p0).projectIsCmd), colontmpD__34, opt_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA242_;
			{
				LA242_:;
			}
			{
				oldNimErrFin242_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___pureZjson_u324(colontmpD__34);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				*nimErr_ = oldNimErrFin242_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		goto LA237_;
LA240_: ;
		{
			if (!opt_p2.allowMissingKeys) goto LA246_;
		}
		goto LA237_;
LA246_: ;
		{
			{
				NimStringV2 colontmpD__35;
				NimStringV2 colontmpD__36;
				tyArray__dyW7vpmfeTYw8kX3EXuaJA T254_;
				if (!NIM_TRUE) goto LA251_;
				colontmpD__35.len = 0; colontmpD__35.p = NIM_NIL;
				colontmpD__36.len = 0; colontmpD__36.p = NIM_NIL;
				T254_[0] = TM__D9aPSI6l3gZsoFvdx9c3FKBg_92;
				T254_[1] = TM__D9aPSI6l3gZsoFvdx9c3FKBg_93;
				colontmpD__35 = pretty__pureZjson_u4827(b_p1, ((NI)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA253_;
				T254_[2] = colontmpD__35;
				colontmpD__36 = percent___extccomp_u2488(T254_, 3);
				if (NIM_UNLIKELY(*nimErr_)) goto LA253_;
				raiseJsonException__stdZjsonutils_u191(TM__D9aPSI6l3gZsoFvdx9c3FKBg_91, colontmpD__36);
				if (NIM_UNLIKELY(*nimErr_)) goto LA253_;
				{
					LA253_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__36);
					eqdestroy___system_u2691(colontmpD__35);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			}
LA251_: ;
		}
LA237_: ;
	}
LA235_: ;
	{
		if (!NIM_TRUE) goto LA259_;
		numX60gensym10__1 += ((NI)1);
		{
			NIM_BOOL T263_;
			tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* colontmpD__37;
			T263_ = (NIM_BOOL)0;
			T263_ = hasKey__pureZjson_u3583(b_p1, TM__D9aPSI6l3gZsoFvdx9c3FKBg_95);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T263_) goto LA264_;
			colontmpD__37 = NIM_NIL;
			numMatchedX60gensym10__1 += ((NI)1);
			colontmpD__37 = X5BX5D___pureZjson_u3478(b_p1, TM__D9aPSI6l3gZsoFvdx9c3FKBg_96);
			if (NIM_UNLIKELY(*nimErr_)) goto LA266_;
			fromJson__stdZjsonutils_u575((&(*a_p0).cmdInput), colontmpD__37, opt_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA266_;
			{
				LA266_:;
			}
			{
				oldNimErrFin266_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___pureZjson_u324(colontmpD__37);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				*nimErr_ = oldNimErrFin266_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		goto LA261_;
LA264_: ;
		{
			if (!opt_p2.allowMissingKeys) goto LA270_;
		}
		goto LA261_;
LA270_: ;
		{
			{
				NimStringV2 colontmpD__38;
				NimStringV2 colontmpD__39;
				tyArray__dyW7vpmfeTYw8kX3EXuaJA T278_;
				if (!NIM_TRUE) goto LA275_;
				colontmpD__38.len = 0; colontmpD__38.p = NIM_NIL;
				colontmpD__39.len = 0; colontmpD__39.p = NIM_NIL;
				T278_[0] = TM__D9aPSI6l3gZsoFvdx9c3FKBg_98;
				T278_[1] = TM__D9aPSI6l3gZsoFvdx9c3FKBg_99;
				colontmpD__38 = pretty__pureZjson_u4827(b_p1, ((NI)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA277_;
				T278_[2] = colontmpD__38;
				colontmpD__39 = percent___extccomp_u2488(T278_, 3);
				if (NIM_UNLIKELY(*nimErr_)) goto LA277_;
				raiseJsonException__stdZjsonutils_u191(TM__D9aPSI6l3gZsoFvdx9c3FKBg_97, colontmpD__39);
				if (NIM_UNLIKELY(*nimErr_)) goto LA277_;
				{
					LA277_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__39);
					eqdestroy___system_u2691(colontmpD__38);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			}
LA275_: ;
		}
LA261_: ;
	}
LA259_: ;
	{
		if (!NIM_TRUE) goto LA283_;
		numX60gensym10__1 += ((NI)1);
		{
			NIM_BOOL T287_;
			tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* colontmpD__40;
			T287_ = (NIM_BOOL)0;
			T287_ = hasKey__pureZjson_u3583(b_p1, TM__D9aPSI6l3gZsoFvdx9c3FKBg_101);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T287_) goto LA288_;
			colontmpD__40 = NIM_NIL;
			numMatchedX60gensym10__1 += ((NI)1);
			colontmpD__40 = X5BX5D___pureZjson_u3478(b_p1, TM__D9aPSI6l3gZsoFvdx9c3FKBg_102);
			if (NIM_UNLIKELY(*nimErr_)) goto LA290_;
			fromJson__stdZjsonutils_u575((&(*a_p0).currentDir), colontmpD__40, opt_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA290_;
			{
				LA290_:;
			}
			{
				oldNimErrFin290_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___pureZjson_u324(colontmpD__40);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				*nimErr_ = oldNimErrFin290_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		goto LA285_;
LA288_: ;
		{
			if (!opt_p2.allowMissingKeys) goto LA294_;
		}
		goto LA285_;
LA294_: ;
		{
			{
				NimStringV2 colontmpD__41;
				NimStringV2 colontmpD__42;
				tyArray__dyW7vpmfeTYw8kX3EXuaJA T302_;
				if (!NIM_TRUE) goto LA299_;
				colontmpD__41.len = 0; colontmpD__41.p = NIM_NIL;
				colontmpD__42.len = 0; colontmpD__42.p = NIM_NIL;
				T302_[0] = TM__D9aPSI6l3gZsoFvdx9c3FKBg_104;
				T302_[1] = TM__D9aPSI6l3gZsoFvdx9c3FKBg_105;
				colontmpD__41 = pretty__pureZjson_u4827(b_p1, ((NI)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA301_;
				T302_[2] = colontmpD__41;
				colontmpD__42 = percent___extccomp_u2488(T302_, 3);
				if (NIM_UNLIKELY(*nimErr_)) goto LA301_;
				raiseJsonException__stdZjsonutils_u191(TM__D9aPSI6l3gZsoFvdx9c3FKBg_103, colontmpD__42);
				if (NIM_UNLIKELY(*nimErr_)) goto LA301_;
				{
					LA301_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__42);
					eqdestroy___system_u2691(colontmpD__41);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			}
LA299_: ;
		}
LA285_: ;
	}
LA283_: ;
	{
		if (!NIM_TRUE) goto LA307_;
		numX60gensym10__1 += ((NI)1);
		{
			NIM_BOOL T311_;
			tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* colontmpD__43;
			T311_ = (NIM_BOOL)0;
			T311_ = hasKey__pureZjson_u3583(b_p1, TM__D9aPSI6l3gZsoFvdx9c3FKBg_107);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T311_) goto LA312_;
			colontmpD__43 = NIM_NIL;
			numMatchedX60gensym10__1 += ((NI)1);
			colontmpD__43 = X5BX5D___pureZjson_u3478(b_p1, TM__D9aPSI6l3gZsoFvdx9c3FKBg_108);
			if (NIM_UNLIKELY(*nimErr_)) goto LA314_;
			fromJson__stdZjsonutils_u575((&(*a_p0).cmdline), colontmpD__43, opt_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA314_;
			{
				LA314_:;
			}
			{
				oldNimErrFin314_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___pureZjson_u324(colontmpD__43);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				*nimErr_ = oldNimErrFin314_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		goto LA309_;
LA312_: ;
		{
			if (!opt_p2.allowMissingKeys) goto LA318_;
		}
		goto LA309_;
LA318_: ;
		{
			{
				NimStringV2 colontmpD__44;
				NimStringV2 colontmpD__45;
				tyArray__dyW7vpmfeTYw8kX3EXuaJA T326_;
				if (!NIM_TRUE) goto LA323_;
				colontmpD__44.len = 0; colontmpD__44.p = NIM_NIL;
				colontmpD__45.len = 0; colontmpD__45.p = NIM_NIL;
				T326_[0] = TM__D9aPSI6l3gZsoFvdx9c3FKBg_110;
				T326_[1] = TM__D9aPSI6l3gZsoFvdx9c3FKBg_111;
				colontmpD__44 = pretty__pureZjson_u4827(b_p1, ((NI)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA325_;
				T326_[2] = colontmpD__44;
				colontmpD__45 = percent___extccomp_u2488(T326_, 3);
				if (NIM_UNLIKELY(*nimErr_)) goto LA325_;
				raiseJsonException__stdZjsonutils_u191(TM__D9aPSI6l3gZsoFvdx9c3FKBg_109, colontmpD__45);
				if (NIM_UNLIKELY(*nimErr_)) goto LA325_;
				{
					LA325_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__45);
					eqdestroy___system_u2691(colontmpD__44);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			}
LA323_: ;
		}
LA309_: ;
	}
LA307_: ;
	{
		if (!NIM_TRUE) goto LA331_;
		numX60gensym10__1 += ((NI)1);
		{
			NIM_BOOL T335_;
			tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* colontmpD__46;
			T335_ = (NIM_BOOL)0;
			T335_ = hasKey__pureZjson_u3583(b_p1, TM__D9aPSI6l3gZsoFvdx9c3FKBg_113);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T335_) goto LA336_;
			colontmpD__46 = NIM_NIL;
			numMatchedX60gensym10__1 += ((NI)1);
			colontmpD__46 = X5BX5D___pureZjson_u3478(b_p1, TM__D9aPSI6l3gZsoFvdx9c3FKBg_114);
			if (NIM_UNLIKELY(*nimErr_)) goto LA338_;
			fromJson__extccomp_u2561((&(*a_p0).depfiles), colontmpD__46, opt_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA338_;
			{
				LA338_:;
			}
			{
				oldNimErrFin338_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___pureZjson_u324(colontmpD__46);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				*nimErr_ = oldNimErrFin338_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		goto LA333_;
LA336_: ;
		{
			if (!opt_p2.allowMissingKeys) goto LA342_;
		}
		goto LA333_;
LA342_: ;
		{
			{
				NimStringV2 colontmpD__47;
				NimStringV2 colontmpD__48;
				tyArray__dyW7vpmfeTYw8kX3EXuaJA T350_;
				if (!NIM_TRUE) goto LA347_;
				colontmpD__47.len = 0; colontmpD__47.p = NIM_NIL;
				colontmpD__48.len = 0; colontmpD__48.p = NIM_NIL;
				T350_[0] = TM__D9aPSI6l3gZsoFvdx9c3FKBg_116;
				T350_[1] = TM__D9aPSI6l3gZsoFvdx9c3FKBg_117;
				colontmpD__47 = pretty__pureZjson_u4827(b_p1, ((NI)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA349_;
				T350_[2] = colontmpD__47;
				colontmpD__48 = percent___extccomp_u2488(T350_, 3);
				if (NIM_UNLIKELY(*nimErr_)) goto LA349_;
				raiseJsonException__stdZjsonutils_u191(TM__D9aPSI6l3gZsoFvdx9c3FKBg_115, colontmpD__48);
				if (NIM_UNLIKELY(*nimErr_)) goto LA349_;
				{
					LA349_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__48);
					eqdestroy___system_u2691(colontmpD__47);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			}
LA347_: ;
		}
LA333_: ;
	}
LA331_: ;
	{
		if (!NIM_TRUE) goto LA355_;
		numX60gensym10__1 += ((NI)1);
		{
			NIM_BOOL T359_;
			tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* colontmpD__49;
			T359_ = (NIM_BOOL)0;
			T359_ = hasKey__pureZjson_u3583(b_p1, TM__D9aPSI6l3gZsoFvdx9c3FKBg_119);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T359_) goto LA360_;
			colontmpD__49 = NIM_NIL;
			numMatchedX60gensym10__1 += ((NI)1);
			colontmpD__49 = X5BX5D___pureZjson_u3478(b_p1, TM__D9aPSI6l3gZsoFvdx9c3FKBg_120);
			if (NIM_UNLIKELY(*nimErr_)) goto LA362_;
			fromJson__stdZjsonutils_u575((&(*a_p0).nimexe), colontmpD__49, opt_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA362_;
			{
				LA362_:;
			}
			{
				oldNimErrFin362_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___pureZjson_u324(colontmpD__49);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				*nimErr_ = oldNimErrFin362_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		goto LA357_;
LA360_: ;
		{
			if (!opt_p2.allowMissingKeys) goto LA366_;
		}
		goto LA357_;
LA366_: ;
		{
			{
				NimStringV2 colontmpD__50;
				NimStringV2 colontmpD__51;
				tyArray__dyW7vpmfeTYw8kX3EXuaJA T374_;
				if (!NIM_TRUE) goto LA371_;
				colontmpD__50.len = 0; colontmpD__50.p = NIM_NIL;
				colontmpD__51.len = 0; colontmpD__51.p = NIM_NIL;
				T374_[0] = TM__D9aPSI6l3gZsoFvdx9c3FKBg_122;
				T374_[1] = TM__D9aPSI6l3gZsoFvdx9c3FKBg_123;
				colontmpD__50 = pretty__pureZjson_u4827(b_p1, ((NI)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA373_;
				T374_[2] = colontmpD__50;
				colontmpD__51 = percent___extccomp_u2488(T374_, 3);
				if (NIM_UNLIKELY(*nimErr_)) goto LA373_;
				raiseJsonException__stdZjsonutils_u191(TM__D9aPSI6l3gZsoFvdx9c3FKBg_121, colontmpD__51);
				if (NIM_UNLIKELY(*nimErr_)) goto LA373_;
				{
					LA373_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__51);
					eqdestroy___system_u2691(colontmpD__50);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			}
LA371_: ;
		}
LA357_: ;
	}
LA355_: ;
	{
		NIM_BOOL T379_;
		T379_ = (NIM_BOOL)0;
		T379_ = opt_p2.allowExtraKeys;
		if (!(T379_)) goto LA380_;
		T379_ = opt_p2.allowMissingKeys;
LA380_: ;
		if (!T379_) goto LA381_;
		colontmpD_ = NIM_TRUE;
		okX60gensym10__1 = colontmpD_;
	}
	goto LA377_;
LA381_: ;
	{
		if (!opt_p2.allowExtraKeys) goto LA384_;
		colontmpD__2 = (numX60gensym10__1 == numMatchedX60gensym10__1);
		okX60gensym10__1 = colontmpD__2;
	}
	goto LA377_;
LA384_: ;
	{
		NI T389_;
		if (!opt_p2.allowMissingKeys) goto LA387_;
		T389_ = (NI)0;
		T389_ = len__pureZjson_u3428(b_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		colontmpD__3 = (T389_ == numMatchedX60gensym10__1);
		okX60gensym10__1 = colontmpD__3;
	}
	goto LA377_;
LA387_: ;
	{
		NIM_BOOL T391_;
		NI T392_;
		T391_ = (NIM_BOOL)0;
		T392_ = (NI)0;
		T392_ = len__pureZjson_u3428(b_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T391_ = (T392_ == numX60gensym10__1);
		if (!(T391_)) goto LA393_;
		T391_ = (numX60gensym10__1 == numMatchedX60gensym10__1);
LA393_: ;
		colontmpD__4 = T391_;
		okX60gensym10__1 = colontmpD__4;
	}
LA377_: ;
	{
		NimStringV2 colontmpD__52;
		NimStringV2 colontmpD__53;
		NimStringV2 colontmpD__54;
		NimStringV2 colontmpD__55;
		tyArray__Seu7uK9aaOSN0BK3EAjjSHw T399_;
		NI T400_;
		if (!!(okX60gensym10__1)) goto LA396_;
		colontmpD__52.len = 0; colontmpD__52.p = NIM_NIL;
		colontmpD__53.len = 0; colontmpD__53.p = NIM_NIL;
		colontmpD__54.len = 0; colontmpD__54.p = NIM_NIL;
		colontmpD__55.len = 0; colontmpD__55.p = NIM_NIL;
		T400_ = (NI)0;
		T400_ = len__pureZjson_u3428(b_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA398_;
		colontmpD__52 = dollar___systemZdollars_u9(T400_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA398_;
		T399_[0] = colontmpD__52;
		colontmpD__53 = dollar___systemZdollars_u9(numX60gensym10__1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA398_;
		T399_[1] = colontmpD__53;
		T399_[2] = TM__D9aPSI6l3gZsoFvdx9c3FKBg_126;
		colontmpD__54 = pretty__pureZjson_u4827(b_p1, ((NI)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA398_;
		T399_[3] = colontmpD__54;
		colontmpD__55 = percent___extccomp_u3055(T399_, 4);
		if (NIM_UNLIKELY(*nimErr_)) goto LA398_;
		raiseJsonException__stdZjsonutils_u191(TM__D9aPSI6l3gZsoFvdx9c3FKBg_125, colontmpD__55);
		if (NIM_UNLIKELY(*nimErr_)) goto LA398_;
		{
			LA398_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__55);
			eqdestroy___system_u2691(colontmpD__54);
			eqdestroy___system_u2691(colontmpD__53);
			eqdestroy___system_u2691(colontmpD__52);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA396_: ;
	}BeforeRet_: ;
}
static N_INLINE(void, X5BX5Deq___pureZjson_u2308)(tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* obj_p0, NimStringV2 key_p1, tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* val_p2) {
	tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* colontmpD_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_ = eqdup___pureZjson_u330(val_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	X5BX5Deq___pureZjson_u739((&(*obj_p0)._kind_6.fields), key_p1, colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g*, toJson__stdZjsonutils_u628)(NimStringV2 a_p0, tyObject_ToJsonOptions__xxRei9adCn4x50jeG886fag opt_p1) {
	tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	result = percent___pureZjson_u2158(a_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g*, toJson__extccomp_u2233)(tyTuple__UV3llMMYFckfui8YMBuUZA* a_p0, tyObject_ToJsonOptions__xxRei9adCn4x50jeG886fag opt_p1) {
	tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	result = newJArray__pureZjson_u506();
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* colontmpD_;
		if (!NIM_TRUE) goto LA3_;
		colontmpD_ = NIM_NIL;
		colontmpD_ = toJson__stdZjsonutils_u628((*a_p0).Field0, opt_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		add__pureZjson_u662(result, colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___pureZjson_u324(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA3_: ;
	{
		tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* colontmpD__2;
		if (!NIM_TRUE) goto LA7_;
		colontmpD__2 = NIM_NIL;
		colontmpD__2 = toJson__stdZjsonutils_u628((*a_p0).Field1, opt_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		add__pureZjson_u662(result, colontmpD__2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___pureZjson_u324(colontmpD__2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA7_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g*, toJson__extccomp_u2205)(tySequence__4eQHGndY6XBYpFOH09apV8Q a_p0, tyObject_ToJsonOptions__xxRei9adCn4x50jeG886fag opt_p1) {
	tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	result = newJArray__pureZjson_u506();
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		tyTuple__UV3llMMYFckfui8YMBuUZA* ai_1;
		NI i_1;
		NI L_1;
		NI T2_;
		ai_1 = (tyTuple__UV3llMMYFckfui8YMBuUZA*)0;
		i_1 = ((NI)0);
		T2_ = a_p0.len;
		L_1 = T2_;
		{
			while (1) {
				tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* colontmpD_;
				if (!(i_1 < L_1)) goto LA4;
				colontmpD_ = NIM_NIL;
				ai_1 = (&a_p0.p->data[i_1]);
				colontmpD_ = toJson__extccomp_u2233((&(*ai_1)), opt_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				add__pureZjson_u662(result, colontmpD_);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				i_1 += ((NI)1);
				eqdestroy___pureZjson_u324(colontmpD_);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			} LA4: ;
		}
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g*, toJson__extccomp_u2254)(tySequence__sM4lkSb7zS6F7OVMvW9cffQ a_p0, tyObject_ToJsonOptions__xxRei9adCn4x50jeG886fag opt_p1) {
	tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	result = newJArray__pureZjson_u506();
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		NimStringV2* ai_1;
		NI i_1;
		NI L_1;
		NI T2_;
		ai_1 = (NimStringV2*)0;
		i_1 = ((NI)0);
		T2_ = a_p0.len;
		L_1 = T2_;
		{
			while (1) {
				tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* colontmpD_;
				if (!(i_1 < L_1)) goto LA4;
				colontmpD_ = NIM_NIL;
				ai_1 = (&a_p0.p->data[i_1]);
				colontmpD_ = toJson__stdZjsonutils_u628((*ai_1), opt_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				add__pureZjson_u662(result, colontmpD_);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				i_1 += ((NI)1);
				eqdestroy___pureZjson_u324(colontmpD_);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			} LA4: ;
		}
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g*, toJson__extccomp_u2282)(NIM_BOOL a_p0, tyObject_ToJsonOptions__xxRei9adCn4x50jeG886fag opt_p1) {
	tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	result = percent___pureZjson_u2184(a_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g*, toJson__extccomp_u2180)(tyObject_BuildCache__lwHTcYFYjgY7FbhZRiNECA* a_p0, tyObject_ToJsonOptions__xxRei9adCn4x50jeG886fag opt_p1) {
	tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	result = newJObject__pureZjson_u443();
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* colontmpD_;
		if (!NIM_TRUE) goto LA3_;
		colontmpD_ = NIM_NIL;
		colontmpD_ = toJson__stdZjsonutils_u628((*a_p0).cacheVersion, opt_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		X5BX5Deq___pureZjson_u2308(result, TM__D9aPSI6l3gZsoFvdx9c3FKBg_127, colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___pureZjson_u324(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA3_: ;
	{
		tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* colontmpD__2;
		if (!NIM_TRUE) goto LA7_;
		colontmpD__2 = NIM_NIL;
		colontmpD__2 = toJson__stdZjsonutils_u628((*a_p0).outputFile, opt_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		X5BX5Deq___pureZjson_u2308(result, TM__D9aPSI6l3gZsoFvdx9c3FKBg_128, colontmpD__2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___pureZjson_u324(colontmpD__2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA7_: ;
	{
		tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* colontmpD__3;
		if (!NIM_TRUE) goto LA11_;
		colontmpD__3 = NIM_NIL;
		colontmpD__3 = toJson__stdZjsonutils_u628((*a_p0).outputLastModificationTime, opt_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		X5BX5Deq___pureZjson_u2308(result, TM__D9aPSI6l3gZsoFvdx9c3FKBg_129, colontmpD__3);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___pureZjson_u324(colontmpD__3);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA11_: ;
	{
		tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* colontmpD__4;
		if (!NIM_TRUE) goto LA15_;
		colontmpD__4 = NIM_NIL;
		colontmpD__4 = toJson__extccomp_u2205((*a_p0).compile, opt_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		X5BX5Deq___pureZjson_u2308(result, TM__D9aPSI6l3gZsoFvdx9c3FKBg_130, colontmpD__4);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___pureZjson_u324(colontmpD__4);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA15_: ;
	{
		tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* colontmpD__5;
		if (!NIM_TRUE) goto LA19_;
		colontmpD__5 = NIM_NIL;
		colontmpD__5 = toJson__extccomp_u2254((*a_p0).link, opt_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		X5BX5Deq___pureZjson_u2308(result, TM__D9aPSI6l3gZsoFvdx9c3FKBg_131, colontmpD__5);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___pureZjson_u324(colontmpD__5);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA19_: ;
	{
		tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* colontmpD__6;
		if (!NIM_TRUE) goto LA23_;
		colontmpD__6 = NIM_NIL;
		colontmpD__6 = toJson__stdZjsonutils_u628((*a_p0).linkcmd, opt_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		X5BX5Deq___pureZjson_u2308(result, TM__D9aPSI6l3gZsoFvdx9c3FKBg_132, colontmpD__6);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___pureZjson_u324(colontmpD__6);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA23_: ;
	{
		tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* colontmpD__7;
		if (!NIM_TRUE) goto LA27_;
		colontmpD__7 = NIM_NIL;
		colontmpD__7 = toJson__extccomp_u2254((*a_p0).extraCmds, opt_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		X5BX5Deq___pureZjson_u2308(result, TM__D9aPSI6l3gZsoFvdx9c3FKBg_133, colontmpD__7);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___pureZjson_u324(colontmpD__7);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA27_: ;
	{
		tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* colontmpD__8;
		if (!NIM_TRUE) goto LA31_;
		colontmpD__8 = NIM_NIL;
		colontmpD__8 = toJson__extccomp_u2254((*a_p0).configFiles, opt_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		X5BX5Deq___pureZjson_u2308(result, TM__D9aPSI6l3gZsoFvdx9c3FKBg_134, colontmpD__8);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___pureZjson_u324(colontmpD__8);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA31_: ;
	{
		tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* colontmpD__9;
		if (!NIM_TRUE) goto LA35_;
		colontmpD__9 = NIM_NIL;
		colontmpD__9 = toJson__extccomp_u2282((*a_p0).stdinInput, opt_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		X5BX5Deq___pureZjson_u2308(result, TM__D9aPSI6l3gZsoFvdx9c3FKBg_135, colontmpD__9);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___pureZjson_u324(colontmpD__9);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA35_: ;
	{
		tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* colontmpD__10;
		if (!NIM_TRUE) goto LA39_;
		colontmpD__10 = NIM_NIL;
		colontmpD__10 = toJson__extccomp_u2282((*a_p0).projectIsCmd, opt_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		X5BX5Deq___pureZjson_u2308(result, TM__D9aPSI6l3gZsoFvdx9c3FKBg_136, colontmpD__10);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___pureZjson_u324(colontmpD__10);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA39_: ;
	{
		tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* colontmpD__11;
		if (!NIM_TRUE) goto LA43_;
		colontmpD__11 = NIM_NIL;
		colontmpD__11 = toJson__stdZjsonutils_u628((*a_p0).cmdInput, opt_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		X5BX5Deq___pureZjson_u2308(result, TM__D9aPSI6l3gZsoFvdx9c3FKBg_137, colontmpD__11);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___pureZjson_u324(colontmpD__11);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA43_: ;
	{
		tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* colontmpD__12;
		if (!NIM_TRUE) goto LA47_;
		colontmpD__12 = NIM_NIL;
		colontmpD__12 = toJson__stdZjsonutils_u628((*a_p0).currentDir, opt_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		X5BX5Deq___pureZjson_u2308(result, TM__D9aPSI6l3gZsoFvdx9c3FKBg_138, colontmpD__12);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___pureZjson_u324(colontmpD__12);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA47_: ;
	{
		tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* colontmpD__13;
		if (!NIM_TRUE) goto LA51_;
		colontmpD__13 = NIM_NIL;
		colontmpD__13 = toJson__stdZjsonutils_u628((*a_p0).cmdline, opt_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		X5BX5Deq___pureZjson_u2308(result, TM__D9aPSI6l3gZsoFvdx9c3FKBg_139, colontmpD__13);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___pureZjson_u324(colontmpD__13);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA51_: ;
	{
		tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* colontmpD__14;
		if (!NIM_TRUE) goto LA55_;
		colontmpD__14 = NIM_NIL;
		colontmpD__14 = toJson__extccomp_u2205((*a_p0).depfiles, opt_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		X5BX5Deq___pureZjson_u2308(result, TM__D9aPSI6l3gZsoFvdx9c3FKBg_140, colontmpD__14);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___pureZjson_u324(colontmpD__14);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA55_: ;
	{
		tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* colontmpD__15;
		if (!NIM_TRUE) goto LA59_;
		colontmpD__15 = NIM_NIL;
		colontmpD__15 = toJson__stdZjsonutils_u628((*a_p0).nimexe, opt_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		X5BX5Deq___pureZjson_u2308(result, TM__D9aPSI6l3gZsoFvdx9c3FKBg_141, colontmpD__15);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___pureZjson_u324(colontmpD__15);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA59_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_ToJsonOptions__xxRei9adCn4x50jeG886fag, initToJsonOptions__stdZjsonutils_u34)(void) {
	tyObject_ToJsonOptions__xxRei9adCn4x50jeG886fag result;
	result.enumMode = ((tyEnum_EnumMode__KZXs5DJfkxxPYeMdTIagsQ)0);
	result.jsonNodeMode = ((tyEnum_JsonNodeMode__HNL4GECPp7laf54R6Sl6LA)0);
	return result;
}
